@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include "xap_Module.h"
@@ -32,6 +32,7 @@
 
 #include "xap_UnixFrameImpl.h"
 #include "xap_UnixDialogHelper.h"
+#include "xap_Gtk2Compat.h"
 
 #ifdef USE_FORK_AND_EXEC_METHOD
 
