@@ -17,8 +17,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -26,13 +26,6 @@
 #include <deque>
 #include <stack>
 
-#ifdef HAVE_LIBXSLT
-#include <libxslt/xslt.h>
-#include <libxslt/xsltInternals.h>
-#include <libxslt/transform.h>
-#include <libxslt/xsltutils.h>
-#endif
-
 #include "fp_types.h"
 #include "ut_debugmsg.h"
 #include "ut_string.h"
@@ -59,6 +52,7 @@
 #include "ut_string_class.h"
 #include "xap_Module.h"
 #include "ut_misc.h"
+#include "ie_math_convert.h"
 
 #ifdef ABI_PLUGIN_BUILTIN
 #define abi_plugin_register abipgn_latex_register
@@ -215,15 +209,15 @@ public:
 	    DELETEP(m_pTableHelper);
 	}
 
-	virtual bool		populate(PL_StruxFmtHandle /*sfh*/,
+	virtual bool		populate(fl_ContainerLayout* /*sfh*/,
 					    const PX_ChangeRecord * /*pcr*/)
 	{
 		return true;	
 	}
 
-	virtual bool		populateStrux(PL_StruxDocHandle sdh,
+	virtual bool		populateStrux(pf_Frag_Strux* sdh,
 						const PX_ChangeRecord * pcr,
-						PL_StruxFmtHandle * psfh)
+						fl_ContainerLayout* * psfh)
 	{
 		UT_ASSERT(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux);
 		const PX_ChangeRecord_Strux * pcrx = static_cast<const PX_ChangeRecord_Strux *> (pcr);
@@ -261,20 +255,20 @@ public:
 		return true;
 	}
 
-	virtual bool		change(PL_StruxFmtHandle /*sfh*/,
+	virtual bool		change(fl_ContainerLayout* /*sfh*/,
 					const PX_ChangeRecord * /*pcr*/)
 	{
 		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		return false;
 	}
 
-	virtual bool		insertStrux(PL_StruxFmtHandle /*sfh*/,
+	virtual bool		insertStrux(fl_ContainerLayout* /*sfh*/,
 					    const PX_ChangeRecord * /*pcr*/,
-					    PL_StruxDocHandle /*sdh*/,
+					    pf_Frag_Strux* /*sdh*/,
 					    PL_ListenerId /*lid*/,
-					    void (* /*pfnBindHandles*/)(PL_StruxDocHandle sdhNew,
+					    void (* /*pfnBindHandles*/)(pf_Frag_Strux* sdhNew,
 									PL_ListenerId lid,
-									PL_StruxFmtHandle sfhNew))
+									fl_ContainerLayout* sfhNew))
 	{
 		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		return false;
@@ -295,29 +289,26 @@ public:
 			    const LaTeX_Analysis_Listener& analysis);
 	virtual ~s_LaTeX_Listener();
 
-	virtual bool		populate(PL_StruxFmtHandle sfh,
+	virtual bool		populate(fl_ContainerLayout* sfh,
 					const PX_ChangeRecord * pcr);
 
-	virtual bool		populateStrux(PL_StruxDocHandle sdh,
+	virtual bool		populateStrux(pf_Frag_Strux* sdh,
 						const PX_ChangeRecord * pcr,
-						PL_StruxFmtHandle * psfh);
+						fl_ContainerLayout* * psfh);
 
-	virtual bool		change(PL_StruxFmtHandle sfh,
+	virtual bool		change(fl_ContainerLayout* sfh,
 					const PX_ChangeRecord * pcr);
 
-	virtual bool		insertStrux(PL_StruxFmtHandle sfh,
+	virtual bool		insertStrux(fl_ContainerLayout* sfh,
 						const PX_ChangeRecord * pcr,
-						PL_StruxDocHandle sdh,
+						pf_Frag_Strux* sdh,
 						PL_ListenerId lid,
-						void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+						void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 							PL_ListenerId lid,
-							PL_StruxFmtHandle sfhNew));
+							fl_ContainerLayout* sfhNew));
 
 	virtual bool		signal(UT_uint32 iSignal);
-#ifdef HAVE_LIBXSLT	
-	static	bool		convertMathMLtoLaTeX(const UT_UTF8String & sMathML,
-							UT_UTF8String & sLaTeX);
-#endif
+
 protected:
 	void				_closeBlock(void);
 	void				_closeCell(void);
@@ -398,15 +389,8 @@ protected:
 					   // or several \cline as appropriate
 	unsigned int	    m_index; // (dynamic, increase only) index into m_pqRect; it is safe
 				     // to skip anything before m_index
-#ifdef HAVE_LIBXSLT
-	static xsltStylesheet *cur;
-#endif
 };
 
-#ifdef HAVE_LIBXSLT
-	xsltStylesheet * s_LaTeX_Listener::cur = NULL;
-#endif
-
 void s_LaTeX_Listener::_closeParagraph(void)
 {
 	if ((!m_bInCell) && (!m_bInFootnote) && (!m_bInEndnote)) m_pie->write("\n");
@@ -1561,13 +1545,6 @@ s_LaTeX_Listener::s_LaTeX_Listener(PD_Document * pDocument, IE_Exp_LaTeX * pie,
 s_LaTeX_Listener::~s_LaTeX_Listener()
 {
 	//if (!m_bInFootnote) return;
-#ifdef HAVE_LIBXSLT
-	if(cur)
-	{
-		xsltFreeStylesheet(cur);
-		cur = NULL;
-	}	
-#endif
 	_closeSection();
 	_handleDataItems();
 	DELETEP(m_pTableHelper);
@@ -1585,62 +1562,7 @@ s_LaTeX_Listener::~s_LaTeX_Listener()
 	m_pie->write("\n\\end{document}\n");
 }
 
-#ifdef HAVE_LIBXSLT
-bool s_LaTeX_Listener::convertMathMLtoLaTeX(const UT_UTF8String & sMathML,
-											UT_UTF8String & sLaTeX)
-{
-	//static xsltStylesheet *cur = NULL;
-	xmlDocPtr doc, res;
-	xmlChar * pLatex = NULL;
-	int len;
-	
-	if (sMathML.empty())
-		// Nothing has failed, but we have nothing to do anyway
-		return false;
-	if (!cur)
-	{
-		UT_UTF8String path(XAP_App::getApp()->getAbiSuiteLibDir());
-		path += "/xsltml/mmltex.xsl";
-
-		cur = xsltParseStylesheetFile((const xmlChar *)(path.utf8_str()));
-		if (!cur)
-		{
-			UT_DEBUGMSG(("convertMathMLtoLaTeX: Parsing stylesheet failed\n"));
-			return false;
-		}
-	}
-	// bad bad bad, apparently on MacOS X, the system libxml2 take a non-const here.
-	doc = xmlParseDoc((xmlChar*)(sMathML.utf8_str()));
-	if (!doc)
-	{
-		xxx_UT_DEBUGMSG(("convertMathMLtoLaTeX: Parsing MathML document failed\n"));
-		return false;
-	}	
-	
-	res = xsltApplyStylesheet(cur, doc, NULL);
-	if (!res)
-	{
-		xxx_UT_DEBUGMSG(("convertMathMLtoLaTeX: Applying stylesheet failed\n"));
-		xmlFreeDoc(doc);
-		return false;
-	}
-	
-	if (xsltSaveResultToString(&pLatex, &len, res, cur) != 0)
-	{
-		xmlFreeDoc(res);
-		xmlFreeDoc(doc);
-		return false;
-	}
-	sLaTeX.assign((const char*)pLatex, len);
-	
-	g_free(pLatex);
-	xmlFreeDoc(res);
-	xmlFreeDoc(doc);
-	return true;
-}
-#endif
-
-bool s_LaTeX_Listener::populate(PL_StruxFmtHandle /*sfh*/,
+bool s_LaTeX_Listener::populate(fl_ContainerLayout* /*sfh*/,
 								   const PX_ChangeRecord * pcr)
 {
 	
@@ -1773,9 +1695,9 @@ bool s_LaTeX_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 						}
 						
 						sMathML.appendBuf(*pByteBuf, myWC);
-						
+
 						if(!convertMathMLtoLaTeX(sMathML, sLatex))
-							return true;
+							return true;		
 						/*The converted sLatex already contains $s*/
 						m_pie->write(sLatex.utf8_str());
 					}
@@ -1800,9 +1722,9 @@ bool s_LaTeX_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 	}
 }
 
-bool s_LaTeX_Listener::populateStrux(PL_StruxDocHandle sdh,
+bool s_LaTeX_Listener::populateStrux(pf_Frag_Strux* sdh,
 										   const PX_ChangeRecord * pcr,
-										   PL_StruxFmtHandle * psfh)
+										   fl_ContainerLayout* * psfh)
 {
 	UT_ASSERT(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux);
 	const PX_ChangeRecord_Strux * pcrx = static_cast<const PX_ChangeRecord_Strux *> (pcr);
@@ -1955,20 +1877,20 @@ bool s_LaTeX_Listener::populateStrux(PL_StruxDocHandle sdh,
 	}
 }
 
-bool s_LaTeX_Listener::change(PL_StruxFmtHandle /*sfh*/,
+bool s_LaTeX_Listener::change(fl_ContainerLayout* /*sfh*/,
 									const PX_ChangeRecord * /*pcr*/)
 {
 	UT_ASSERT(0);						// this function is not used.
 	return false;
 }
 
-bool s_LaTeX_Listener::insertStrux(PL_StruxFmtHandle /*sfh*/,
+bool s_LaTeX_Listener::insertStrux(fl_ContainerLayout* /*sfh*/,
 									 const PX_ChangeRecord * /*pcr*/,
-									 PL_StruxDocHandle /*sdh*/,
+									 pf_Frag_Strux* /*sdh*/,
 									 PL_ListenerId /* lid */,
-									 void (* /*pfnBindHandles*/)(PL_StruxDocHandle /* sdhNew */,
+									 void (* /*pfnBindHandles*/)(pf_Frag_Strux* /* sdhNew */,
 																 PL_ListenerId /* lid */,
-																 PL_StruxFmtHandle /* sfhNew */))
+																 fl_ContainerLayout* /* sfhNew */))
 {
 	UT_ASSERT(0);						// this function is not used.
 	return false;
