@@ -15,8 +15,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 // Class definition include
@@ -82,38 +82,40 @@ void ODe_Main_Listener::openSection(const PP_AttrProp* pAP,
 
     if (ODe_Style_PageLayout::hasPageLayoutInfo(pAP)) {
 
-        ODe_Style_PageLayout* pPageLayout;        
-
         if (m_isFirstSection) {
             // Use stantard master page and page layout.
 
-            pPageLayout = m_rDocumentData.m_stylesAutoStyles.getPageLayout("Standard");
+            ODe_Style_PageLayout* pPageLayout = m_rDocumentData.m_stylesAutoStyles.getPageLayout("Standard");
+            pPageLayout->fetchAttributesFromAbiSection(pAP);
             pMPStyle = m_rDocumentData.m_masterStyles.pick("Standard");
+            pMPStyle->fetchAttributesFromAbiSection(pAP);
             UT_DEBUGMSG(("Got PageLayout %p AutoStyles %p \n",pPageLayout,&m_rDocumentData.m_stylesAutoStyles));
             m_isFirstSection = false;
 
         } else {
 
             UT_UTF8String styleName;
-            UT_UTF8String layoutName;
-    		
     		UT_UTF8String_sprintf(styleName, "MasterStyle%d",
                                   m_rDocumentData.m_masterStyles.size());
     		
+            pMPStyle = new ODe_Style_MasterPage(styleName.utf8_str(), "");
+            pMPStyle->fetchAttributesFromAbiSection(pAP);
 
-        	pPageLayout = m_rDocumentData.m_stylesAutoStyles.addPageLayout();
-        	layoutName = pPageLayout->getName();
-            
-            pMPStyle = new ODe_Style_MasterPage(styleName.utf8_str(),
-                                                layoutName.utf8_str());
+            // only write out a new MasterPage when it actually has some
+            // useful properties in it
+            if (pMPStyle->hasProperties())
+            {
+                ODe_Style_PageLayout* pPageLayout = m_rDocumentData.m_stylesAutoStyles.addPageLayout();
+                pPageLayout->fetchAttributesFromAbiSection(pAP);
+                pMPStyle->setPageLayoutName(pPageLayout->getName());
 
-            m_rDocumentData.m_masterStyles.insert(styleName.utf8_str(),pMPStyle);
-            pendingMasterPageStyleChange = true;
-            masterPageStyleName = styleName;
+                m_rDocumentData.m_masterStyles.insert(styleName.utf8_str(),pMPStyle);
+                pendingMasterPageStyleChange = true;
+                masterPageStyleName = styleName;
+            }
         }
+
         
-        pMPStyle->fetchAttributesFromAbiSection(pAP);
-        pPageLayout->fetchAttributesFromAbiSection(pAP);
 	//
 	// OK Set up a "standard" default set of properties
 	//
@@ -200,7 +202,8 @@ bool ODe_Main_Listener::_isHeaderFooterSection(const PP_AttrProp* pAP) const {
     
     ok = pAP->getAttribute("type", pValue);
     if (ok && pValue != NULL) {
-        if (!strcmp(pValue, "header") || !strcmp(pValue, "footer")) {
+        if (!strcmp(pValue, "header") || !strcmp(pValue, "header-even") || 
+            !strcmp(pValue, "footer") || !strcmp(pValue, "footer-even")) {
             return true;
         }
     }
@@ -252,8 +255,18 @@ void ODe_Main_Listener::_openHeaderFooterSection(
             }
         }
         
-    } else {
-        // It's a footer
+    } else if (!strcmp("header-even", pValue)) {
+        
+        for (i=0; i<count && !ok; i++) {
+            pMPageStyle = (*pMasterPageVector)[i];
+            pValue = pMPageStyle->getAbiHeaderEvenId().utf8_str();
+            if (!strcmp(pId, pValue)) {
+                ok = true; // found it. get out of this "for" loop
+                pTextOutput =  pMPageStyle->getHeaderEvenContentTempFile();
+            }
+        }
+
+    } else if (!strcmp("footer", pValue)) {
         
         for (i=0; i<count && !ok; i++) {
             pMPageStyle = (*pMasterPageVector)[i];
@@ -263,6 +276,17 @@ void ODe_Main_Listener::_openHeaderFooterSection(
                 pTextOutput = pMPageStyle->getFooterContentTempFile();
             }
         }
+
+    } else if (!strcmp("footer-even", pValue)) {
+        
+        for (i=0; i<count && !ok; i++) {
+            pMPageStyle = (*pMasterPageVector)[i];
+            pValue = pMPageStyle->getAbiFooterEvenId().utf8_str();
+            if (!strcmp(pId, pValue)) {
+                ok = true; // found it. get out of this "for" loop
+                pTextOutput = pMPageStyle->getFooterEvenContentTempFile();
+            }
+        }
     }
 
     if (!ok) {
