@@ -16,8 +16,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 // Class definition include
@@ -1047,7 +1047,9 @@ write(UT_UTF8String& rOutput, const UT_UTF8String& rSpacesOffset) const {
     }
     
     rOutput += rSpacesOffset;
-    rOutput += "<style:section-properties>\n";
+    // We don't need to balance text columns automatically because in Abiword 
+    // we set distribution explicitly by inserting VTAB's
+    rOutput += "<style:section-properties text:dont-balance-text-columns=\"true\">\n";
     
     rOutput += rSpacesOffset;
     rOutput += " <style:columns";
@@ -1428,7 +1430,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
                 case FL_TAB_DECIMAL:
                 {
                     UT_LocaleInfo locale(UT_LocaleInfo::system());
-                    UT_LocaleTransactor t(LC_NUMERIC, locale.toString().utf8_str());
+                    UT_LocaleTransactor t(LC_NUMERIC, locale.toString().c_str());
                     
                     // AbiWord always uses the locale-defined decimal point as the
                     // decimal tab character. See fp_Line::_calculateWidthOfRun()
@@ -2354,9 +2356,8 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     // Left border
 
     ok = rAP.getProperty("left-style", pValue);
-    UT_ASSERT (ok && pValue != NULL);
 
-    if (pValue && (*pValue == '0')) {
+    if (!ok || (pValue && (*pValue == '0'))) {
         m_borderLeft = "none";
     } else {
         ok = rAP.getProperty("left-thickness", pValue);
@@ -2378,9 +2379,8 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     // Right border
 
     ok = rAP.getProperty("right-style", pValue);
-    UT_ASSERT (ok && pValue != NULL);
     
-    if (pValue && (*pValue == '0')) {
+    if (!ok || (pValue && (*pValue == '0'))) {
         m_borderRight = "none";
     } else {
         ok = rAP.getProperty("right-thickness", pValue);
@@ -2402,9 +2402,8 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     // Top border
     
     ok = rAP.getProperty("top-style", pValue);
-    UT_ASSERT (ok && pValue != NULL);
     
-    if (pValue && (*pValue == '0')) {
+    if (!ok || (pValue && (*pValue == '0'))) {
         m_borderTop = "none";
     } else {
         ok = rAP.getProperty("top-thickness", pValue);
@@ -2427,9 +2426,8 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     
     ok = rAP.getProperty("bot-style", pValue);
-    UT_ASSERT (ok && pValue != NULL);
     
-    if (pValue && (*pValue == '0')) {
+    if (!ok || (pValue && (*pValue == '0'))) {
         m_borderBottom = "none";
     } else {
         ok = rAP.getProperty("bot-thickness", pValue);
@@ -2478,8 +2476,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("position-to", pValue);
     UT_ASSERT (ok && pValue != NULL);
-
-    if (!strcmp(pValue, "block-above-text")) {
+    if (ok && pValue && !strcmp(pValue, "block-above-text")) {
         m_horizontalRel = "paragraph";
         m_verticalRel = "paragraph";
     } else {
