@@ -16,8 +16,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
  
 // Class definition include
@@ -151,6 +151,13 @@ void ODe_Table_Listener::openTable(const PP_AttrProp* pAP,
 	    {
                 if (!buffer.empty()) 
 		{
+                    if (cnt >= vecStyles.size())
+                    {
+                        UT_DEBUGMSG(("table-rel-column-props and table-column-props "
+                                     "have mismatched column counts! ignoring "
+                                     "further values.\n"));
+                        break;
+                    }
                     pStyle = vecStyles.getNthItem(cnt);
 		    cnt++;
                     pStyle->setRelColumnWidth(buffer.c_str());
@@ -426,6 +433,19 @@ void ODe_Table_Cell::loadAbiProps(const PP_AttrProp* pAP) {
                               m_bottomAttach - m_topAttach);
     }
 
+    ok = pAP->getProperty(PT_XMLID, pValue);
+    if( ok && pValue )
+    {
+        m_xmlid = pValue;
+    }
+    UT_DEBUGMSG(("ODe_Table_Cell::loadAbiProps(1) ok:%d xmlid:%s \n",ok, pValue));
+    ok = pAP->getProperty("xmlid", pValue);
+    if( ok && pValue )
+    {
+        m_xmlid = pValue;
+    }
+    UT_DEBUGMSG(("ODe_Table_Cell::loadAbiProps(2) ok:%d xmlid:%s \n",ok, pValue));
+    
     
 }
 
@@ -443,6 +463,9 @@ void ODe_Table_Cell::write(GsfOutput* pTableOutput, const UT_UTF8String& rSpaces
       ODe_writeAttribute(output, "table:number-columns-spanned", m_numberColumnsSpanned);
     if(m_numberRowsSpanned.size() > 0)
       ODe_writeAttribute(output, "table:number-rows-spanned", m_numberRowsSpanned);
+    if( !m_xmlid.empty() )
+      ODe_writeAttribute(output, "xml:id", m_xmlid);
+        
     output += ">\n";
     ODe_writeUTF8String(pTableOutput, output);
     gsf_output_write (pTableOutput, gsf_output_size (m_pTextContent),
