@@ -13,8 +13,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #include "ut_types.h"
@@ -983,7 +983,7 @@ void s_XSL_FO_Listener::_handleMath(PT_AttrPropIndex api)
 	_tagOpenClose(img, true, false);
 }
 
-bool s_XSL_FO_Listener::populate(PL_StruxFmtHandle /*sfh*/,
+bool s_XSL_FO_Listener::populate(fl_ContainerLayout* /*sfh*/,
 								 const PX_ChangeRecord * pcr)
 {
 	switch (pcr->getType())
@@ -1069,9 +1069,9 @@ bool s_XSL_FO_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 	}
 }
 
-bool s_XSL_FO_Listener::populateStrux(PL_StruxDocHandle sdh,
+bool s_XSL_FO_Listener::populateStrux(pf_Frag_Strux* sdh,
 									  const PX_ChangeRecord * pcr,
-									  PL_StruxFmtHandle * psfh)
+									  fl_ContainerLayout* * psfh)
 {
 	UT_ASSERT(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux);
 	const PX_ChangeRecord_Strux * pcrx = static_cast<const PX_ChangeRecord_Strux *> (pcr);
@@ -1260,20 +1260,20 @@ bool s_XSL_FO_Listener::signal(UT_uint32 /* iSignal */)
 	return false;
 }
 
-bool s_XSL_FO_Listener::change(PL_StruxFmtHandle /*sfh*/,
+bool s_XSL_FO_Listener::change(fl_ContainerLayout* /*sfh*/,
 							   const PX_ChangeRecord * /*pcr*/)
 {
 	UT_ASSERT(0);						// this function is not used.
 	return false;
 }
 
-bool s_XSL_FO_Listener::insertStrux(PL_StruxFmtHandle /*sfh*/,
+bool s_XSL_FO_Listener::insertStrux(fl_ContainerLayout* /*sfh*/,
 									const PX_ChangeRecord * /*pcr*/,
-									PL_StruxDocHandle /*sdh*/,
+									pf_Frag_Strux* /*sdh*/,
 									PL_ListenerId /* lid */,
-									void (* /*pfnBindHandles*/)(PL_StruxDocHandle /* sdhNew */,
+									void (* /*pfnBindHandles*/)(pf_Frag_Strux* /* sdhNew */,
 																PL_ListenerId /* lid */,
-																PL_StruxFmtHandle /* sfhNew */))
+																fl_ContainerLayout* /* sfhNew */))
 {
 	UT_ASSERT(0);						// this function is not used.
 	return false;
