@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #define WIN32_LEAN_AND_MEAN
@@ -43,6 +43,7 @@
 #include "ut_debugmsg.h"
 #include "ut_assert.h"
 #include "ut_string.h"
+#include "ut_std_string.h"
 #include "ut_Win32OS.h"
 #include "ut_Win32LocaleString.h"
 
@@ -157,6 +158,8 @@ void GR_Win32Graphics::_constructorCommonCode(HDC hdc)
 	m_pArPens = new GR_Win32Graphics::CACHE_PEN [_MAX_CACHE_PENS];
 	memset (m_pArPens, 0, _MAX_CACHE_PENS*sizeof(CACHE_PEN));
 	m_nArPenPos = 0;
+
+	_DoubleBuffering_SetUpDummyBuffer();
 }
 
 GR_Win32Graphics::GR_Win32Graphics(HDC hdc, HWND hwnd)
@@ -240,6 +243,8 @@ GR_Win32Graphics::~GR_Win32Graphics()
 
 	DELETEP(m_pFontGUI);
 	
+	_DoubleBuffering_ReleaseDummyBuffer();
+
 	if(m_printHDC && m_printHDC != m_defPrintHDC)
 		DeleteDC(m_printHDC);
 	
@@ -276,7 +281,7 @@ GR_Font* GR_Win32Graphics::getGUIFont(void)
 		// lazily grab this (once)
 		HFONT f = (HFONT) GetStockObject(DEFAULT_GUI_FONT);
 		LOGFONTW lf;
-		int iRes = GetObjectW(f, sizeof(LOGFONTW), &lf);
+		/*int iRes =*/ GetObjectW(f, sizeof(LOGFONTW), &lf);
 		m_pFontGUI = _newFont(lf, 0, m_hdc, m_hdc);
 		UT_ASSERT(m_pFontGUI);
 		DeleteObject(f);
@@ -420,14 +425,14 @@ void GR_Win32Graphics::drawChar(UT_UCSChar Char, UT_sint32 xoff, UT_sint32 yoff)
 	// Reference Microsoft knowledge base:
 	// Q145754 - PRB ExtTextOutW or TextOutW Unicode Text Output Is Blank
 	LOGFONTW lf;
-	int iRes = GetObjectW(m_pFont->getFontHandle(), sizeof(LOGFONTW), &lf);
+	UT_DebugOnly<int> iRes = GetObjectW(m_pFont->getFontHandle(), sizeof(LOGFONTW), &lf);
 	UT_ASSERT(iRes);
 	if (UT_IsWinNT() == false && lf.lfCharSet == SYMBOL_CHARSET)
 	{
 		// Symbol character handling for Win9x
 		char str[sizeof(UT_UCS2Char)];
 
-		int iConverted = WideCharToMultiByte(CP_ACP, NULL,
+		int iConverted = WideCharToMultiByte(CP_ACP, 0,
 			(LPCWSTR) &aChar, 1,
 			str, sizeof(str), NULL, NULL);
 		ExtTextOutA(m_hdc, xoff, yoff, 0, NULL, str, iConverted, NULL);
@@ -520,7 +525,7 @@ void GR_Win32Graphics::drawChars(const UT_UCSChar* pChars,
 	{
 		// Symbol character handling for Win9x
 		char* str = new char[iLength * sizeof(UT_UCS2Char)];
-		int iConverted = WideCharToMultiByte(CP_ACP, NULL,
+		int iConverted = WideCharToMultiByte(CP_ACP, 0,
 			(LPCWSTR) currentChars, iLength,
 			str, iLength * sizeof(UT_UCSChar), NULL, NULL);
 
@@ -1136,7 +1141,7 @@ void GR_Win32Graphics::setClipRect(const UT_Rect* pRect)
 	// not work for other things.  For now leave code in place.
 	// return;
 
-	int res;
+	UT_DebugOnly<int> res;
 	m_pRect = pRect;
 	if (pRect)
 	{
@@ -1243,7 +1248,7 @@ void GR_Win32Graphics::drawImage(GR_Image* pImg, UT_sint32 xDest, UT_sint32 yDes
 	
 	if (iRes == GDI_ERROR)
 	{
-		DWORD err = GetLastError();
+		UT_DebugOnly<DWORD> err = GetLastError();
 		UT_DEBUGMSG(("StretchDIBits failed with err %d\n", err));
 	}
 }
@@ -1587,11 +1592,11 @@ GR_Win32Font::GR_Win32Font(LOGFONTW & lf, double fPoints, HDC hdc, HDC printHDC)
 			// Setting the m_hashKey 
 			wchar_t lpFaceName[1000];
 			
-			GetTextFaceW(printHDC, 1000*sizeof(wchar_t), lpFaceName );
+			GetTextFaceW(printHDC, 1000, lpFaceName );
 
 			_updateFontYMetrics(hdc, printHDC);
 
-			UT_String_sprintf(m_hashKey, "%s-%d-%d-%d-%d-%d-%d-%d",
+			m_hashKey = UT_std_string_sprintf("%s-%ld-%ld-%d-%d-%d-%d-%d",
 							  lpFaceName,
 							  m_tm.tmHeight, m_tm.tmWeight, m_tm.tmItalic, m_tm.tmUnderlined,
 							  m_tm.tmStruckOut,
@@ -1649,12 +1654,12 @@ GR_Win32Font::~GR_Win32Font()
 	// (this whole thing is rather messy)
 
 	DWORD dwObjType;
-	bool bIsDC;
+	bool bIsDC = false;
 
 	if(m_hdc) 
 	{
 		dwObjType = GetObjectType((HGDIOBJ)m_hdc);
-		bIsDC = dwObjType == OBJ_DC || dwObjType == OBJ_MEMDC;
+		bIsDC = (dwObjType == OBJ_DC || dwObjType == OBJ_MEMDC);
 	}
 
 	for (UT_sint32 i = 0; i < m_allocFonts.getItemCount(); ++i)
@@ -1693,7 +1698,7 @@ void GR_Win32Font::_updateFontYMetrics(HDC hdc, HDC printHDC)
 	}
 
 	// we have to remeasure if (a) the printer changed, or (b) the primary device changed
-	if(printHDC != m_yhdc || hdc != m_hdc)
+	if(printHDC != m_yhdc)
 	{
 		GetTextMetricsW(printHDC,&m_tm);
 
@@ -1720,7 +1725,6 @@ void GR_Win32Font::_updateFontYMetrics(HDC hdc, HDC printHDC)
 
 		// now remember what HDC these values are for
 		m_yhdc = printHDC;
-		m_hdc = hdc;
 	}
 }
 
@@ -1830,15 +1834,6 @@ bool GR_Win32Font::glyphBox(UT_UCS4Char g, UT_Rect & rec, GR_Graphics * pG)
 	if(printDC == pWin32Gr->getPrimaryDC())
 		pWin32Gr->setDCFontAllocNo(getAllocNumber());
 	
-	if (printDC != m_hdc)
-	{
-		// invalidate cached info when we change hdc's.
-		// this is probably unnecessary except when
-		// sharing a font with screen and printer.
-		_clearAnyCachedInfo();
-		m_hdc = printDC;
-	}
-	
 	DWORD iRet = GDI_ERROR;
 	
 	if (UT_IsWinNT())
@@ -1984,23 +1979,10 @@ UT_sint32 GR_Win32Font::measureUnRemappedChar(UT_UCSChar c, UT_uint32 * /*height
 void GR_Win32Font::selectFontIntoDC(GR_Graphics * pGr, HDC hdc)
 {
 	HFONT hFont = getDisplayFont(pGr);
-	HGDIOBJ hRet = SelectObject(hdc, hFont);
+	UT_DebugOnly<HGDIOBJ> hRet = SelectObject(hdc, hFont);
 
 	// hate having to do the cast, here
 	UT_ASSERT_HARMLESS( hRet != (void*)GDI_ERROR);
-	
-	if (hdc != m_hdc)
-	{
-		// invalidate cached info when we change hdc's.
-		// this is probably unnecessary except when
-		// sharing a font with screen and printer.
-		// TODO consider changing our invalidate test
-		// TODO to not invalidate if old and new are
-		// TODO both on screen.
-
-		_clearAnyCachedInfo();
-		m_hdc = hdc;
-	}
 }
 
 void GR_Win32Graphics::polygon(UT_RGBColor& c,UT_Point *pts,UT_uint32 nPoints)
@@ -2479,7 +2461,7 @@ bool GR_Win32Graphics::fixDevMode(HGLOBAL hDevMode)
 		// we are knees deep in crap here ... log it into the users profile, so we have
 		// some debug info to go on
 		UT_String msg;
-		UT_String_sprintf(msg,"DEVMODE too small [%s, needs %d, got %d + %d]",
+		UT_String_sprintf(msg,"DEVMODE too small [%s, needs %ld, got %d + %d]",
 						  (char*)& pDM->dmDeviceName, dwNeeded, pDM->dmSize, pDM->dmDriverExtra);
 		LOG_WIN32_EXCPT(msg.c_str());
 		ClosePrinter(hPrinter);
@@ -2563,3 +2545,107 @@ HDC GR_Win32Graphics::createbestmetafilehdc()
   if (printerinfo) free(printerinfo);
   return besthdc;
 }
+
+void GR_Win32Graphics::getWidthAndHeightFromHWND(HWND h, int &width, int &height)
+{
+	RECT clientRect;
+	GetClientRect(h, &clientRect);
+	
+	width = clientRect.right - clientRect.left;
+	height = clientRect.bottom - clientRect.top;
+
+	UT_ASSERT(clientRect.left == 0 && clientRect.top == 0);
+}
+
+void GR_Win32Graphics::_DeviceContext_MeasureBitBltCopySpeed(HDC sourceHdc, HDC destHdc, int width, int height)
+{
+	LARGE_INTEGER t1, t2, freq;
+	
+	QueryPerformanceCounter(&t1);
+	BitBlt(destHdc, 0, 0, width, height, sourceHdc, 0, 0, SRCCOPY);
+	QueryPerformanceCounter(&t2);
+	
+	QueryPerformanceFrequency(&freq);
+#if DEBUG
+	double blitSpeed = ((double)(t2.QuadPart - t1.QuadPart)) / ((double)freq.QuadPart);
+
+	UT_DEBUGMSG(("ASFRENT: measured BitBlt speed: %lfs [client rectangle W = %d, H = %d]\n", 
+			blitSpeed, width, height));
+#endif
+}
+
+void GR_Win32Graphics::_DeviceContext_SwitchToBuffer()
+{
+	// get client area size
+	int height(0), width(0);
+	getWidthAndHeightFromHWND(m_hwnd, width, height);
+
+	// set up the buffer
+	m_bufferHdc = _DoubleBuffering_CreateBuffer(m_hdc, width, height);
+
+	// copy the screen to the buffer
+	BitBlt(m_bufferHdc, 0, 0, width, height, m_hdc, 0, 0, SRCCOPY);
+
+	// save the current hdc & switch
+	_HDCSwitchStack.push(new _HDCSwitchRecord(m_hdc));
+	m_hdc = m_bufferHdc;
+}
+
+void GR_Win32Graphics::_DeviceContext_SwitchToScreen()
+{
+	_DeviceContext_RestorePrevHDCFromStack();
+
+	// get client area size
+	int height(0), width(0);
+	getWidthAndHeightFromHWND(m_hwnd, width, height);
+	
+	// copy any modifications back to the screen
+	BitBlt(m_hdc, 0, 0, width, height, m_bufferHdc, 0, 0, SRCCOPY);
+	
+	// free used resources
+	_DoubleBuffering_ReleaseBuffer(m_bufferHdc);
+}
+
+void GR_Win32Graphics::_DeviceContext_RestorePrevHDCFromStack()
+{
+	_HDCSwitchRecord *switchRecord;
+	_HDCSwitchStack.pop((void**)&switchRecord);
+	m_hdc = switchRecord->oldHdc;
+	delete switchRecord;
+}
+
+void GR_Win32Graphics::_DeviceContext_SuspendDrawing()
+{
+	// save the current hdc & switch them!
+	_HDCSwitchStack.push(new _HDCSwitchRecord(m_hdc));
+	m_hdc = m_dummyHdc;
+}
+
+void GR_Win32Graphics::_DeviceContext_ResumeDrawing()
+{
+	_DeviceContext_RestorePrevHDCFromStack();
+}
+
+void GR_Win32Graphics::_DoubleBuffering_SetUpDummyBuffer()
+{
+	m_dummyHdc = _DoubleBuffering_CreateBuffer(m_hdc, 0, 0);
+}
+
+void GR_Win32Graphics::_DoubleBuffering_ReleaseDummyBuffer()
+{
+	_DoubleBuffering_ReleaseBuffer(m_dummyHdc);
+}
+
+HDC GR_Win32Graphics::_DoubleBuffering_CreateBuffer(HDC compatibleWith, int width, int height)
+{
+	HDC resultingHdc = CreateCompatibleDC(compatibleWith);
+	HBITMAP bufferBitmap = CreateCompatibleBitmap(compatibleWith, width, height);
+	SelectObject(resultingHdc, bufferBitmap);
+	return resultingHdc;
+}
+
+void GR_Win32Graphics::_DoubleBuffering_ReleaseBuffer(HDC hdc)
+{
+	DeleteObject(GetCurrentObject(hdc, OBJ_BITMAP));
+	DeleteDC(hdc);
+}
