@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,6 +43,11 @@
 #include <glib/gstdio.h>
 #include <libxml/encoding.h>
 
+#if TOOLKIT_COCOA
+#include <CoreFoundation/CoreFoundation.h>
+#include <ApplicationServices/ApplicationServices.h>
+#endif
+
 #ifdef WITH_GSF_INPUT_HTTP
 #include <gsf/gsf-input-http.h>
 #endif
@@ -59,14 +64,14 @@
 #  include <gsf-gnome/gsf-output-gnomevfs.h>
 #endif
 
-#ifdef HAVE_GTK214
-// needed for gtk_show_uri()
+#ifdef TOOLKIT_GTK_ALL
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
-#elif defined(WITH_GNOMEVFS)
+#if defined(WITH_GNOMEVFS)
 // needed for gnome_vfs_url_show()
 #include <libgnomevfs/gnome-vfs-utils.h>
 #endif
+#endif
 
 #if defined G_OS_WIN32
 #include <windows.h>
@@ -1037,8 +1042,14 @@ UT_go_dirname_from_uri (const char *uri, gboolean brief)
 #else
 	char *uri_dirname = g_path_get_dirname (uri);
 	dirname = uri_dirname ? UT_go_filename_from_uri (uri_dirname) : NULL;
-	dirname = dirname ? g_strconcat ("file://", dirname, NULL) : NULL;
-	g_free (uri_dirname);
+	if(uri_dirname) {
+		g_free (uri_dirname);
+	}
+	uri_dirname = dirname ? g_strconcat ("file://", dirname, NULL) : NULL;
+	if(dirname) {
+		g_free (dirname);
+	}
+	dirname = uri_dirname;
 #endif
 
 	if (brief && dirname &&
@@ -1443,15 +1454,20 @@ UT_go_get_file_permissions (char const *uri)
 	}
 
 	gnome_vfs_file_info_unref (file_info);
-#elif ! defined (G_OS_WIN32)
+#else
+
+#if GLIB_CHECK_VERSION(2,26,0) || defined(G_OS_WIN32)
+	GStatBuf file_stat;
+#else
 	struct stat file_stat;
+#endif
 	char *filename = UT_go_filename_from_uri (uri);
 	int result = filename ? g_stat (filename, &file_stat) : -1;
 
 	g_free (filename);
 	if (result == 0) {
 		file_permissions = g_new0 (UT_GOFilePermissions, 1);
-
+#if ! defined (G_OS_WIN32)
 		/* Owner  Permissions */
 		file_permissions->owner_read    = ((file_stat.st_mode & S_IRUSR) != 0);
 		file_permissions->owner_write   = ((file_stat.st_mode & S_IWUSR) != 0);
@@ -1466,6 +1482,13 @@ UT_go_get_file_permissions (char const *uri)
 		file_permissions->others_read    = ((file_stat.st_mode & S_IROTH) != 0);
 		file_permissions->others_write   = ((file_stat.st_mode & S_IWOTH) != 0);
 		file_permissions->others_execute = ((file_stat.st_mode & S_IXOTH) != 0);
+#else
+		/* Windows */
+		/* Owner  Permissions */
+		file_permissions->owner_read    = ((file_stat.st_mode & S_IREAD) != 0);
+		file_permissions->owner_write   = ((file_stat.st_mode & S_IWRITE) != 0);
+		file_permissions->owner_execute = ((file_stat.st_mode & S_IEXEC) != 0);
+#endif
 	}
 #endif
 	return file_permissions;
@@ -1652,8 +1675,11 @@ UT_go_file_get_date_changed (char const *uri)
 }
 
 /* ------------------------------------------------------------------------- */
-
-#ifndef WITH_GNOMEVFS
+#ifdef TOOLKIT_GTK_ALL
+// We need this for systems where gtk_show_uri() is broken
+// Don't get me started.
+// Note that if gtk_show_uri() fails but returns true, then
+// there is nothing that can be done.
 static char *
 check_program (char const *prog)
 {
@@ -1666,29 +1692,10 @@ check_program (char const *prog)
 		return NULL;
 	return g_strdup (prog);
 }
-#endif
 
-#ifdef G_OS_WIN32
-#include "ut_Win32LocaleString.h"
-#endif
-
-GError *
-UT_go_url_show (gchar const *url)
+static void 
+fallback_open_uri(const gchar* url, GError** err)
 {
-#ifdef G_OS_WIN32
-	UT_Win32LocaleString str;
-	str.fromUTF8 (url);
-	ShellExecuteW (NULL, L"open", str.c_str(), NULL, NULL, SW_SHOWNORMAL);
-	return NULL;
-#else
-	GError *err = NULL;
-#ifdef HAVE_GTK214
-	gtk_show_uri (NULL, url, GDK_CURRENT_TIME, &err);
-	return err;
-#elif defined(WITH_GNOMEVFS)
-	gnome_vfs_url_show (url);
-	return err;
-#else
 	gchar *browser = NULL;
 	gchar *clean_url = NULL;
 
@@ -1697,6 +1704,7 @@ UT_go_url_show (gchar const *url)
 
 	if (browser == NULL) {
 		static char const * const browsers[] = {
+			"xdg-open",             /* XDG. you shouldn't need anything else */
 			"sensible-browser",	/* debian */
 			"epiphany",		/* primary gnome */
 			"galeon",		/* secondary gnome */
@@ -1721,7 +1729,7 @@ UT_go_url_show (gchar const *url)
 		gchar **argv = NULL;
 		char   *cmd_line = g_strconcat (browser, " %1", NULL);
 
-		if (g_shell_parse_argv (cmd_line, &argc, &argv, &err)) {
+		if (g_shell_parse_argv (cmd_line, &argc, &argv, err)) {
 			/* check for '%1' in an argument and substitute the url
 			 * otherwise append it */
 			gint i;
@@ -1744,13 +1752,51 @@ UT_go_url_show (gchar const *url)
 				argv[argc-1] = NULL;
 			}
 			g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
-				NULL, NULL, NULL, &err);
+				NULL, NULL, NULL, err);
 			g_strfreev (argv);
 		}
 		g_free (cmd_line);
 	}
 	g_free (browser);
 	g_free (clean_url);
+}
+#endif
+
+#ifdef G_OS_WIN32
+#undef _
+#include "ut_Win32LocaleString.h"
+#endif
+
+GError *
+UT_go_url_show (gchar const *url)
+{
+#ifdef G_OS_WIN32
+	UT_Win32LocaleString str;
+	str.fromUTF8 (url);
+	ShellExecuteW (NULL, L"open", str.c_str(), NULL, NULL, SW_SHOWNORMAL);
+	return NULL;
+#elif TOOLKIT_COCOA
+	CFStringRef urlStr = CFStringCreateWithCString(kCFAllocatorDefault, url, kCFStringEncodingUTF8);
+	CFURLRef cfUrl = CFURLCreateWithString(kCFAllocatorDefault, urlStr, NULL);
+	OSStatus err = LSOpenCFURLRef(cfUrl, NULL);
+	CFRelease(cfUrl);
+	CFRelease(urlStr);
+	if (err != noErr) {
+		;
+	}
+	return NULL;
+#else
+	GError *err = NULL;
+#if GTK_CHECK_VERSION(2,14,0)
+	if(!gtk_show_uri (NULL, url, GDK_CURRENT_TIME, &err)) {
+		fallback_open_uri(url, &err);
+	}
+	return err;
+#elif defined(WITH_GNOMEVFS)
+	gnome_vfs_url_show (url);
+	return err;
+#else
+	fallback_open_uri(url, &err);
 	return err;
 #endif
 #endif
