@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifndef UTVECTOR_H
@@ -159,7 +159,7 @@ public:
 
 /*!
     sizehint: expected size of the vector
-    
+
     baseincr: the amount by which the internal storage will grow once the sizehint has
               been reached (until then, the size gets doubled)
 
@@ -177,9 +177,9 @@ UT_GenericVector<T>::UT_GenericVector(UT_sint32 sizehint, UT_sint32 baseincr, bo
 
 template <class T>
 UT_GenericVector<T>::UT_GenericVector(const UT_GenericVector<T>& utv)
-  : m_pEntries(NULL), m_iCount(0), m_iSpace(0), 
-  m_iCutoffDouble(utv.m_iCutoffDouble), 
-  m_iPostCutoffIncrement(utv.m_iPostCutoffIncrement) 
+  : m_pEntries(NULL), m_iCount(0), m_iSpace(0),
+  m_iCutoffDouble(utv.m_iCutoffDouble),
+  m_iPostCutoffIncrement(utv.m_iPostCutoffIncrement)
 {
 	copy(&utv);
 }
@@ -201,9 +201,9 @@ void UT_GenericVector<T>::clear()
 {
 	if(m_iCount > m_iCutoffDouble)
 	{
-		UT_DEBUGMSG(("Vector contained %d entries, allocated %d slots\n", m_iCount, m_iSpace));
+		xxx_UT_DEBUGMSG(("Vector contained %d entries, allocated %d slots\n", m_iCount, m_iSpace));
 	}
-	
+
 	m_iCount = 0;
 	memset(m_pEntries, 0, m_iSpace * sizeof(T));
 }
@@ -214,9 +214,9 @@ UT_GenericVector<T>::~UT_GenericVector()
 {
 	if(m_iCount >  m_iCutoffDouble)
 	{
-		UT_DEBUGMSG(("Vector contained %d entries, allocated %d slots\n", m_iCount, m_iSpace));
+		xxx_UT_DEBUGMSG(("Vector contained %d entries, allocated %d slots\n", m_iCount, m_iSpace));
 	}
-	
+
 	FREEP(m_pEntries);
 }
 
