@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include "xap_UnixCustomWidget.h"
@@ -38,15 +38,23 @@ void XAP_UnixCustomWidget::queueDraw(const UT_Rect *clip)
 	}
 }
 
+#if GTK_CHECK_VERSION(3,0,0)
 void XAP_UnixCustomWidget::_fe::draw(XAP_UnixCustomWidget *self, cairo_t *cr)
+#else
+void XAP_UnixCustomWidget::_fe::expose(XAP_UnixCustomWidget *self, GdkEventExpose *ev)
+#endif
 {
+#if GTK_CHECK_VERSION(3,0,0)
 	GdkEventExpose *ev = reinterpret_cast<GdkEventExpose *>(gtk_get_current_event());
+#endif
 	UT_Rect r(
 			ev->area.x,
 			ev->area.y,
 			ev->area.width,
 			ev->area.height
 		);
+#if GTK_CHECK_VERSION(3,0,0)
 	self->m_cr = cr;
+#endif
 	self->draw(&r);
 }
