@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 // 9/4/04 Updated to use GtkTreeView , Tim O'Brien (obrientimo@vuw.ac.nz)
@@ -461,7 +461,8 @@ void XAP_UnixDialog_FontChooser::sizeRowChanged(void)
 
 void XAP_UnixDialog_FontChooser::fgColorChanged(void)
 {
-	gtk_color_selection_get_current_color (GTK_COLOR_SELECTION(m_colorSelector), &m_currentFGColor);
+	gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER(m_colorSelector),
+							   &m_currentFGColor);
 	UT_RGBColor * rgbcolor = UT_UnixGdkColorToRGBColor(m_currentFGColor);
 	UT_HashColor hash_color;
 	const char * c = hash_color.setColor(*rgbcolor);
@@ -473,7 +474,8 @@ void XAP_UnixDialog_FontChooser::fgColorChanged(void)
 
 void XAP_UnixDialog_FontChooser::bgColorChanged(void)
 {
-	gtk_color_selection_get_current_color (GTK_COLOR_SELECTION(m_bgcolorSelector), &m_currentBGColor);
+	gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER(m_bgcolorSelector),
+								&m_currentBGColor);
 	UT_RGBColor * rgbcolor = UT_UnixGdkColorToRGBColor(m_currentBGColor);
 	UT_HashColor hash_color;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_checkTransparency), FALSE);
@@ -491,9 +493,9 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindow(void)
 	GtkWidget *vboxMain;
 	GtkWidget *vboxOuter;
 
-	UT_UTF8String s;
+	std::string s;
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_FontTitle,s);
-	windowFontSelection = abiDialogNew ( "font dialog", TRUE, s.utf8_str() ) ;
+	windowFontSelection = abiDialogNew ( "font dialog", TRUE, s.c_str() ) ;
 	gtk_window_set_position(GTK_WINDOW(windowFontSelection), GTK_WIN_POS_CENTER_ON_PARENT);
 #if !GTK_CHECK_VERSION(3,0,0)
 	gtk_dialog_set_has_separator(GTK_DIALOG(windowFontSelection), FALSE);
@@ -571,10 +573,10 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 							  reinterpret_cast<GDestroyNotify>(g_object_unref));
 	gtk_widget_show (table1);
 
-	UT_UTF8String s;
+	std::string s;
 	// Label for first page of the notebook
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_FontTab,s);
-	labelTabFont = gtk_label_new (s.utf8_str());
+	labelTabFont = gtk_label_new (s.c_str());
 	gtk_widget_show (labelTabFont);
 //
 // Make first page of the notebook
@@ -592,7 +594,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 					  static_cast<GtkAttachOptions>(GTK_EXPAND | GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_FontLabel,s);
-	labelFont = gtk_label_new (s.utf8_str());
+	labelFont = gtk_label_new (s.c_str());
 	gtk_widget_set_name (labelFont, "labelFont");
 	g_object_ref (labelFont);
 	g_object_set_data_full (G_OBJECT (window1), "labelFont", labelFont,
@@ -630,7 +632,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_StyleLabel,s);
-	labelStyle = gtk_label_new (s.utf8_str());
+	labelStyle = gtk_label_new (s.c_str());
 	gtk_widget_set_name (labelStyle, "labelStyle");
 	g_object_ref (labelStyle);
 	g_object_set_data_full (G_OBJECT (window1), "labelStyle", labelStyle,
@@ -668,7 +670,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_SizeLabel,s);
-	labelSize = gtk_label_new (s.utf8_str());
+	labelSize = gtk_label_new (s.c_str());
 	gtk_widget_set_name (labelSize, "labelSize");
 	g_object_ref (labelSize);
 	g_object_set_data_full (G_OBJECT (window1), "labelSize", labelSize,
@@ -706,7 +708,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_EffectsFrameLabel,s);
-	frameEffects = gtk_frame_new (s.utf8_str());
+	frameEffects = gtk_frame_new (s.c_str());
 	gtk_frame_set_shadow_type(GTK_FRAME(frameEffects), GTK_SHADOW_NONE);
 	gtk_widget_show (frameEffects);
 	gtk_box_pack_start(GTK_BOX (vboxmisc), frameEffects, 0,0, 6);
@@ -716,7 +718,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 	gtk_container_add (GTK_CONTAINER (frameEffects), tblEffectRows);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_StrikeoutCheck,s);
-	checkbuttonStrikeout = gtk_check_button_new_with_label (s.utf8_str());
+	checkbuttonStrikeout = gtk_check_button_new_with_label (s.c_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonStrikeout), 5);
 	gtk_widget_show (checkbuttonStrikeout);
 	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonStrikeout, 0, 1, 0, 1,
@@ -724,7 +726,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_UnderlineCheck,s);
-	checkbuttonUnderline = gtk_check_button_new_with_label (s.utf8_str());
+	checkbuttonUnderline = gtk_check_button_new_with_label (s.c_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonUnderline), 5);
 	gtk_widget_show (checkbuttonUnderline);
 	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonUnderline, 1, 2, 0, 1,
@@ -732,7 +734,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_OverlineCheck,s);
-	checkbuttonOverline = gtk_check_button_new_with_label (s.utf8_str());
+	checkbuttonOverline = gtk_check_button_new_with_label (s.c_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonOverline), 5);
 	gtk_widget_show (checkbuttonOverline);
 	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonOverline, 2, 3, 0, 1,
@@ -740,7 +742,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_HiddenCheck,s);
-	checkbuttonHidden = gtk_check_button_new_with_label (s.utf8_str());
+	checkbuttonHidden = gtk_check_button_new_with_label (s.c_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonHidden), 5);
 	gtk_widget_show (checkbuttonHidden);
 	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonHidden, 3, 4, 0, 1,
@@ -750,7 +752,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 	/* subscript/superscript */
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_SubScript,s);
-	checkbuttonSubscript = gtk_check_button_new_with_label (s.utf8_str());
+	checkbuttonSubscript = gtk_check_button_new_with_label (s.c_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonSubscript), 5);
 	gtk_widget_show (checkbuttonSubscript);
 	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonSubscript, 0, 1, 1, 2,
@@ -758,7 +760,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_SuperScript,s);
-	checkbuttonSuperscript = gtk_check_button_new_with_label (s.utf8_str());
+	checkbuttonSuperscript = gtk_check_button_new_with_label (s.c_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonSuperscript), 5);
 	gtk_widget_show (checkbuttonSuperscript);
 	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonSuperscript, 1, 2, 1, 2,
@@ -773,7 +775,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
     // Label for second page of the notebook
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_ColorTab,s);
-	labelTabColor = gtk_label_new (s.utf8_str());
+	labelTabColor = gtk_label_new (s.c_str());
 	gtk_widget_show (labelTabColor);
 
 //
@@ -781,9 +783,9 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 //
     gtk_notebook_append_page(GTK_NOTEBOOK(notebookMain), hbox1,labelTabColor);
 
-	colorSelector = gtk_color_selection_new ();
+	colorSelector = gtk_color_chooser_widget_new ();
 	gtk_container_set_border_width(GTK_CONTAINER(colorSelector), 6);
-	gtk_color_selection_set_has_opacity_control(GTK_COLOR_SELECTION(colorSelector), FALSE);
+	gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(colorSelector), FALSE);
 	gtk_widget_show (colorSelector);
 	gtk_box_pack_start (GTK_BOX (hbox1), colorSelector, TRUE, TRUE, 0);
 
@@ -795,16 +797,16 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
     // Label for third page of the notebook
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_BGColorTab,s);
-	labelTabBGColor = gtk_label_new (s.utf8_str());
+	labelTabBGColor = gtk_label_new (s.c_str());
 	gtk_widget_show (labelTabBGColor);
 //
 // Make third page of the notebook
 //
     gtk_notebook_append_page(GTK_NOTEBOOK(notebookMain), vboxBG,labelTabBGColor);
 
-	colorBGSelector = gtk_color_selection_new ();
+	colorBGSelector = gtk_color_chooser_widget_new ();
 	gtk_container_set_border_width(GTK_CONTAINER(colorBGSelector), 6);
-	gtk_color_selection_set_has_opacity_control(GTK_COLOR_SELECTION(colorBGSelector), FALSE);
+	gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(colorBGSelector), FALSE);
 	gtk_widget_show (colorBGSelector);
 	gtk_box_pack_start (GTK_BOX (vboxBG), colorBGSelector, TRUE, TRUE, 0);
 
@@ -812,7 +814,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 // Make a toggle button to set hightlight color transparent
 //
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_TransparencyCheck,s);
-	GtkWidget * checkbuttonTrans = gtk_check_button_new_with_label (s.utf8_str());
+	GtkWidget * checkbuttonTrans = gtk_check_button_new_with_label (s.c_str());
 	gtk_container_set_border_width(GTK_CONTAINER(checkbuttonTrans), 6);
 	gtk_widget_show (checkbuttonTrans);
 	gtk_box_pack_start (GTK_BOX (vboxBG), checkbuttonTrans, TRUE, TRUE, 0);
@@ -918,12 +920,20 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 	// real-time updating of the color so we can refresh our preview
 	// text
 	g_signal_connect(G_OBJECT(colorSelector),
+#if GTK_CHECK_VERSION(3,4,0)
+			 "color-activated",
+#else
 			 "color-changed", //"event",
+#endif
 			 G_CALLBACK(s_color_update),
 			 static_cast<gpointer>(this));
 
 	g_signal_connect(G_OBJECT(colorBGSelector),
+#if GTK_CHECK_VERSION(3,4,0)
+			 "color-activated",
+#else
 			 "color-changed", //"event",
+#endif
 			 G_CALLBACK(s_bgcolor_update),
 			 static_cast<gpointer>(this));
 
@@ -1096,10 +1106,10 @@ void XAP_UnixDialog_FontChooser::runModal(XAP_Frame * pFrame)
 		UT_RGBColor c;
 		UT_parseColor(sColor.c_str(), c);
 
-		GdkColor *color = UT_UnixRGBColorToGdkColor(c);
+		GdkRGBA *color = UT_UnixRGBColorToGdkRGBA(c);
 		m_currentFGColor = *color;
-		gdk_color_free(color);
-		gtk_color_selection_set_current_color(GTK_COLOR_SELECTION(m_colorSelector), &m_currentFGColor);
+		gdk_rgba_free(color);
+		gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(m_colorSelector), &m_currentFGColor);
 	}
 	else
 	{
@@ -1108,7 +1118,7 @@ void XAP_UnixDialog_FontChooser::runModal(XAP_Frame * pFrame)
 		// the cases except where the user specifically enters -1 for
 		// all Red, Green and Blue attributes manually.  This user
 		// should expect it not to touch the color.  :)
-		gtk_color_selection_set_current_color(GTK_COLOR_SELECTION(m_colorSelector), &m_funkyColor);
+		gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(m_colorSelector), &m_funkyColor);
 	}
 
 	// Set color in the color selector
@@ -1118,11 +1128,11 @@ void XAP_UnixDialog_FontChooser::runModal(XAP_Frame * pFrame)
 		UT_RGBColor c;
 		UT_parseColor(sBGCol.c_str(), c);
 
-		GdkColor *color = UT_UnixRGBColorToGdkColor(c);
+		GdkRGBA *color = UT_UnixRGBColorToGdkRGBA(c);
 		m_currentBGColor = *color;
-		gdk_color_free(color);
+		gdk_rgba_free(color);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_checkTransparency), FALSE);
-		gtk_color_selection_set_current_color(GTK_COLOR_SELECTION(m_bgcolorSelector), &m_currentBGColor);
+		gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(m_bgcolorSelector), &m_currentBGColor);
 	}
 	else
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_checkTransparency), TRUE);
