@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
   /*
@@ -1159,7 +1159,12 @@ gint XAP_UnixFrameImpl::_fe::key_press_event(GtkWidget* w, GdkEventKey* e)
 
 	// stop emission for keys that would take the focus away from the document widget
 	switch (e->keyval) {
-	case GDK_KEY_Tab: case GDK_KEY_Left: case GDK_KEY_Up: case GDK_KEY_Right: case GDK_KEY_Down: 
+	case GDK_KEY_Tab: 
+	case GDK_KEY_ISO_Left_Tab:
+	case GDK_KEY_Left: 
+	case GDK_KEY_Up: 
+	case GDK_KEY_Right: 
+	case GDK_KEY_Down: 
 		return TRUE;
 		break;
 	}
@@ -1231,8 +1236,11 @@ gint XAP_UnixFrameImpl::_fe::expose(GtkWidget * w, GdkEventExpose* pExposeEvent)
 		rClip.height = pGr->tlu(pExposeEvent->area.height)+1;
 #if GTK_CHECK_VERSION(3,0,0)
 		static_cast<GR_CairoGraphics *>(pGr)->setCairo(cr);
-#endif
 		pView->draw(&rClip);
+		static_cast<GR_CairoGraphics *>(pGr)->setCairo(NULL);
+#else
+		pView->draw(&rClip);
+#endif
 	}
 	return FALSE;
 }
