@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include <gtk/gtk.h>
@@ -344,13 +344,7 @@ restart_widget (AbiTable *table)
 	table->selected_rows = init_rows;
 	table->total_cols = my_max(init_cols + 1, 5);
 	table->total_rows = my_max(init_rows + 1, 6);
-
-#if GTK_CHECK_VERSION(2,24,0)
-	g_signal_emit_by_name(table, "button-release-event");
-#else
-	gtk_button_released(GTK_BUTTON(table));
-#endif
-
+	g_signal_emit_by_name(table, "released");
 	gtk_widget_hide(GTK_WIDGET(table->window));
 }
 
