@@ -16,8 +16,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -654,6 +654,20 @@ UT_sint32 AD_Document::getRevisionIndxFromId(UT_uint32 iId) const
 	return -1;
 }
 
+/**
+ * Should we pay attention to change tracking?
+ */
+bool AD_Document::usingChangeTracking() const
+{
+    bool ret = false;
+    
+    ret |= isMarkRevisions();
+    ret |= ( getHighestRevisionId() > 1 );
+
+    return ret;
+}
+
+
 
 UT_uint32 AD_Document::getHighestRevisionId() const
 {
