@@ -15,14 +15,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include <string.h>
 
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
@@ -31,7 +30,6 @@
 #include "ut_bytebuf.h"
 #include "ut_wctomb.h"
 #include "ut_iconv.h"
-#include "ut_exception.h"
 #include "ut_Language.h"
 
 #include "xap_App.h"
@@ -63,7 +61,7 @@ const gchar * XAP_StringSet::getLanguageName(void) const
 	return m_szLanguageName;
 }
 
-bool XAP_StringSet::getValue(XAP_String_Id id, const char * inEncoding, UT_String &s) const
+bool XAP_StringSet::getValue(XAP_String_Id id, const char * inEncoding, std::string &s) const
 {
 	const char * toTranslate = getValue(id);
 
@@ -78,7 +76,7 @@ bool XAP_StringSet::getValue(XAP_String_Id id, const char * inEncoding, UT_Strin
 	        UT_iconv_t conv = UT_iconv_open(inEncoding, m_encoding.c_str());
 		UT_return_val_if_fail(UT_iconv_isValid(conv), false);
 	  
-		char * translated = UT_convert_cd(toTranslate, strlen (toTranslate), conv, NULL, NULL);
+		char * translated = UT_convert_cd(toTranslate, strlen (toTranslate)+1, conv, NULL, NULL);
 		
 		UT_iconv_close(conv);
 		
@@ -91,13 +89,9 @@ bool XAP_StringSet::getValue(XAP_String_Id id, const char * inEncoding, UT_Strin
 	return true;
 }
 
-bool XAP_StringSet::getValueUTF8(XAP_String_Id id, UT_UTF8String & s) const
+bool XAP_StringSet::getValueUTF8(XAP_String_Id id, std::string & s) const
 {	
-        UT_String s_;
-	bool b = getValue(id, "UTF-8", s_);
-	if (b)
-	        s = s_.c_str();
-	return b;
+	return getValue(id, "UTF-8", s);
 }
 
 void XAP_StringSet::setEncoding(const gchar * inEncoding)
@@ -165,7 +159,7 @@ XAP_DiskStringSet::XAP_DiskStringSet(XAP_App * pApp)
 
 XAP_DiskStringSet::~XAP_DiskStringSet(void)
 {
-	UT_sint32 kLimit = static_cast<UT_sint32>(m_vecStringsXAP.getItemCount());
+	UT_sint32 kLimit = m_vecStringsXAP.getItemCount();
 	UT_sint32 k;
 
 	for (k=kLimit-1; k>=0; k--)
@@ -397,10 +391,6 @@ void XAP_DiskStringSet::startElement(const gchar *name, const gchar **atts)
 		const gchar ** a;
 		for (a = atts; (*a); a += 2)
 		{
-#ifdef DEBUG
-			// require a value for each attribute keyword
-			g_warning("untranslated string '%s'\n", a[0]);
-#endif
 			if (strcmp(a[0], "class") == 0)
 				continue;
 
@@ -455,25 +445,6 @@ bool XAP_DiskStringSet::loadStringsFromDisk(const char * szFilename)
 		goto Cleanup;
 	}
 
-	// we succeeded in parsing the file,
-	// now check for higher-level consistency.
-
-#ifdef DEBUG
-	{
-		// TODO should we promote this test to be production code
-		// TODO and maybe raise a message box ??
-		UT_uint32 kLimit = G_N_ELEMENTS(s_map);
-		UT_uint32 k;
-
-		for (k=0; k<kLimit; k++)
-		{
-			const gchar * szValue = XAP_DiskStringSet::getValue(s_map[k].id);
-			if (!szValue || !*szValue)
-				UT_DEBUGMSG(("WARNING: Translation for id [%s] not found.\n",s_map[k].szName));
-		}
-	}
-#endif
-
 	bResult = true;
 
 Cleanup:
