@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -1133,7 +1133,7 @@ void fl_AutoNum::_setParentID(UT_uint32 iParentID)
 
 void fl_AutoNum::update(UT_uint32 start)
 {
-	//UT_DEBUGMSG(("Updating List %d  There are %d items here \n",m_iID,m_pItems.getItemCount()));
+	UT_DEBUGMSG(("Updating List %d  There are %d items here \n",m_iID,m_pItems.getItemCount()));
 	if (isUpdating())
 		return;
 	//_calculateLabelStr(0);
