@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include <string.h>
@@ -121,7 +121,7 @@ UT_UTF8String  TOCEntry::getFullLabel(void)
 	return sFull;
 }
 
-fl_TOCLayout::fl_TOCLayout(FL_DocLayout* pLayout, fl_DocSectionLayout* pDocSL, PL_StruxDocHandle sdh, PT_AttrPropIndex indexAP, fl_ContainerLayout * pMyContainerLayout) 
+fl_TOCLayout::fl_TOCLayout(FL_DocLayout* pLayout, fl_DocSectionLayout* pDocSL, pf_Frag_Strux* sdh, PT_AttrPropIndex indexAP, fl_ContainerLayout * pMyContainerLayout) 
  	: fl_SectionLayout(pLayout, sdh, indexAP, FL_SECTION_TOC,FL_CONTAINER_TOC,PTX_SectionTOC,pMyContainerLayout),
 	  m_bNeedsRebuild(false),
 	  m_bNeedsFormat(true),
@@ -177,7 +177,7 @@ fl_TOCLayout::~fl_TOCLayout()
 */
 PT_DocPosition fl_TOCLayout::getDocPosition(void) 
 {
-	PL_StruxDocHandle sdh = getStruxDocHandle();
+	pf_Frag_Strux* sdh = getStruxDocHandle();
     return 	m_pLayout->getDocument()->getStruxPosition(sdh);
 }
 
@@ -211,9 +211,9 @@ void fl_TOCLayout::setSelected(bool bIsSelected)
 UT_uint32 fl_TOCLayout::getLength(void)
 {
 	PT_DocPosition startPos = getDocPosition();
-	PL_StruxDocHandle sdhEnd = NULL;
-	PL_StruxDocHandle sdhStart = getStruxDocHandle();
-	bool bres;
+	pf_Frag_Strux* sdhEnd = NULL;
+	pf_Frag_Strux* sdhStart = getStruxDocHandle();
+	UT_DebugOnly<bool> bres;
 	bres = m_pLayout->getDocument()->getNextStruxOfType(sdhStart,PTX_EndTOC,&sdhEnd);
 	UT_ASSERT(bres && sdhEnd);
 	PT_DocPosition endPos = m_pLayout->getDocument()->getStruxPosition(sdhEnd);
@@ -224,18 +224,19 @@ UT_uint32 fl_TOCLayout::getLength(void)
 
 bool fl_TOCLayout::bl_doclistener_insertEndTOC(fl_ContainerLayout*,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew))
+																	  fl_ContainerLayout* sfhNew))
 {
 	// The endFootnote strux actually needs a format handle to to this Footnote layout.
-	// so we bind to this layout.
+	// so we bind to this layout. We also set a pointer to keep track of the endTOC strux.
 
 		
-	PL_StruxFmtHandle sfhNew = static_cast<PL_StruxFmtHandle>(this);
+	fl_ContainerLayout* sfhNew = this;
 	pfnBindHandles(sdh,lid,sfhNew);
+	setEndStruxDocHandle(sdh);
 
 //
 // increment the insertion point in the view.
@@ -251,20 +252,7 @@ bool fl_TOCLayout::bl_doclistener_insertEndTOC(fl_ContainerLayout*,
 	}
 	m_bHasEndTOC = true;
 
-	m_pLayout->fillTOC(this);
-	if(m_bTOCHeading)
-	{
-		PD_Style * pStyle = NULL;
-		m_pDoc->getStyle(m_sTOCHeadingStyle.utf8_str(), &pStyle);
-		if(pStyle == NULL)
-		{
-			m_pDoc->getStyle("Heading 1", &pStyle);
-		}
-		PT_AttrPropIndex indexAP = pStyle->getIndexAP();
-		
-		fl_BlockLayout * pNewBlock = static_cast<fl_BlockLayout *>(insert(getStruxDocHandle(),NULL,indexAP,FL_CONTAINER_BLOCK));
-		pNewBlock->_doInsertTOCHeadingRun(0);
-	}
+	fillTOC();
 
 	return true;
 }
@@ -397,20 +385,7 @@ bool fl_TOCLayout::verifyBookmarkAssumptions()
 	if(m_bFalseBookmarkEstimate || (m_bMissingBookmark && m_pDoc->isBookmarkUnique(m_sRangeBookmark.utf8_str())))
 	{
 		// this bookmark either does not exist, or it was positioned earlier than we assumed
-		m_pLayout->fillTOC(this);
-	}
-	if(m_bTOCHeading)
-	{
-		PD_Style * pStyle = NULL;
-		m_pDoc->getStyle(m_sTOCHeadingStyle.utf8_str(), &pStyle);
-		if(pStyle == NULL)
-		{
-			m_pDoc->getStyle("Heading 1", &pStyle);
-		}
-		PT_AttrPropIndex indexAP = pStyle->getIndexAP();
-		
-		fl_BlockLayout * pNewBlock = static_cast<fl_BlockLayout *>(insert(getStruxDocHandle(),NULL,indexAP,FL_CONTAINER_BLOCK));
-		pNewBlock->_doInsertTOCHeadingRun(0);
+		fillTOC();
 	}
 
 	return true;
@@ -422,7 +397,7 @@ bool fl_TOCLayout::verifyBookmarkAssumptions()
     by associated bookmark. This parameter has default value true, but the caller can specify false
     if the block is known to be inside the TOC range (the range checking is involved, so if this
     function is called from a loop, it is desirable that most of the range verification is taken
-    outside the loop -- see for example fl_DocLayout::fillTOC())
+    outside the loop -- see for example fillTOC())
 */
 bool fl_TOCLayout::addBlock(fl_BlockLayout * pBlock, bool bVerifyRange)
 {
@@ -875,6 +850,7 @@ bool fl_TOCLayout::removeBlock(fl_BlockLayout * pBlock)
 	return false;
 }
 
+
 fl_BlockLayout * fl_TOCLayout::findMatchingBlock(fl_BlockLayout * pBlock)
 {
 	TOCEntry * pThisEntry = NULL;
@@ -1151,7 +1127,7 @@ bool fl_TOCLayout::_isStyleInTOC(UT_UTF8String & sStyle, UT_UTF8String & sTOCSty
 bool fl_TOCLayout::isBlockInTOC(fl_BlockLayout * pBlock)
 {
 	TOCEntry * pEntry = NULL;
-	PL_StruxDocHandle sdh = pBlock->getStruxDocHandle();
+	pf_Frag_Strux* sdh = pBlock->getStruxDocHandle();
 	UT_sint32 i = 0;
 	for(i=0; i< m_vecEntries.getItemCount(); i++)
 	{
@@ -1172,7 +1148,7 @@ UT_UTF8String & fl_TOCLayout::getTOCListLabel(fl_BlockLayout * pBlock)
 	static UT_UTF8String str;
 	str.clear();
 	TOCEntry * pEntry = NULL;
-	PL_StruxDocHandle sdh = pBlock->getStruxDocHandle();
+	pf_Frag_Strux* sdh = pBlock->getStruxDocHandle();
 	UT_sint32 i = 0;
 	bool bFound = false;
 	for(i=0; i< m_vecEntries.getItemCount(); i++)
@@ -1410,20 +1386,7 @@ void fl_TOCLayout::_createTOCContainer(void)
 	pTOCContainer->setWidth(iWidth);
 	if(m_bHasEndTOC)
 	{
-		m_pLayout->fillTOC(this);
-	}
-	if(m_bTOCHeading)
-	{
-		PD_Style * pStyle = NULL;
-		m_pDoc->getStyle(m_sTOCHeadingStyle.utf8_str(), &pStyle);
-		if(pStyle == NULL)
-		{
-			m_pDoc->getStyle("Heading 1", &pStyle);
-		}
-		PT_AttrPropIndex indexAP = pStyle->getIndexAP();
-		
-		fl_BlockLayout * pNewBlock = static_cast<fl_BlockLayout *>(insert(getStruxDocHandle(),NULL,indexAP,FL_CONTAINER_BLOCK));
-		pNewBlock->_doInsertTOCHeadingRun(0);
+	    fillTOC();
 	}
 }
 
@@ -1566,10 +1529,10 @@ void fl_TOCLayout::format(void)
 	m_bNeedsReformat = false;
 }
 
-UT_UTF8String fl_TOCLayout::getDefaultHeading()
+std::string fl_TOCLayout::getDefaultHeading()
 {
 	const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
-	UT_UTF8String sDefaultHeading;
+	std::string sDefaultHeading;
 	pSS->getValueUTF8(AP_STRING_ID_TOC_TocHeading, sDefaultHeading);
 	return sDefaultHeading;
 }
@@ -2316,7 +2279,7 @@ fl_TOCListener::~fl_TOCListener()
 {
 }
 
-bool fl_TOCListener::populate(PL_StruxFmtHandle sfh,
+bool fl_TOCListener::populate(fl_ContainerLayout* sfh,
 								 const PX_ChangeRecord * pcr)
 {
 	if (!m_bListening)
@@ -2372,9 +2335,9 @@ bool fl_TOCListener::populate(PL_StruxFmtHandle sfh,
 	return bResult;
 }
 
-bool fl_TOCListener::populateStrux(PL_StruxDocHandle sdh,
+bool fl_TOCListener::populateStrux(pf_Frag_Strux* sdh,
 									  const PX_ChangeRecord * pcr,
-									  PL_StruxFmtHandle * psfh)
+									  fl_ContainerLayout* * psfh)
 {
 	UT_ASSERT(m_pTOCL);
 
@@ -2401,7 +2364,7 @@ bool fl_TOCListener::populateStrux(PL_StruxDocHandle sdh,
 				return false;
 			}
 			m_pCurrentBL = pBL;
-			*psfh = static_cast<PL_StruxFmtHandle>(pBL);
+			*psfh = pBL;
 		}
 
 	}
@@ -2417,7 +2380,7 @@ bool fl_TOCListener::populateStrux(PL_StruxDocHandle sdh,
 	return true;
 }
 
-bool fl_TOCListener::change(PL_StruxFmtHandle /*sfh*/,
+bool fl_TOCListener::change(fl_ContainerLayout* /*sfh*/,
 							   const PX_ChangeRecord * /*pcr*/)
 {
 	UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
@@ -2425,13 +2388,13 @@ bool fl_TOCListener::change(PL_StruxFmtHandle /*sfh*/,
 	return false;
 }
 
-bool fl_TOCListener::insertStrux(PL_StruxFmtHandle /*sfh*/,
+bool fl_TOCListener::insertStrux(fl_ContainerLayout* /*sfh*/,
 									const PX_ChangeRecord * /*pcr*/,
-									PL_StruxDocHandle /*sdh*/,
+									pf_Frag_Strux* /*sdh*/,
 									PL_ListenerId /*lid*/,
-									void (* /*pfnBindHandles*/)(PL_StruxDocHandle sdhNew,
+									void (* /*pfnBindHandles*/)(pf_Frag_Strux* sdhNew,
 																PL_ListenerId lid,
-																PL_StruxFmtHandle sfhNew))
+																fl_ContainerLayout* sfhNew))
 {
 	UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 
@@ -2446,3 +2409,129 @@ bool fl_TOCListener::signal(UT_uint32 /*iSignal*/)
 }
 
 
+bool fl_TOCLayout::fillTOC(void)
+{
+    fl_DocSectionLayout * pDSL = getDocLayout()->getFirstSection();
+    fl_BlockLayout * pBlock = NULL;
+    fl_ContainerLayout * pCL = static_cast<fl_ContainerLayout *>(pDSL);
+    while(pCL && pCL->getContainerType() != FL_CONTAINER_BLOCK)
+    {
+	pCL = pCL->getFirstLayout();
+    }
+    if(pCL == NULL)
+    {
+	return false;
+    }
+    if(pCL->getContainerType() != FL_CONTAINER_BLOCK)
+    {
+	return false;
+    }
+    UT_UTF8String sStyle;
+    pBlock = static_cast<fl_BlockLayout *>(pCL);
+    bool filled = false;
+    
+    const gchar * pBookmark = getRangeBookmarkName().size() ? getRangeBookmarkName().utf8_str() : NULL;
+    
+    if(pBookmark)
+    {
+	if(m_pDoc->isBookmarkUnique(pBookmark))
+	{
+	    // bookmark does not exist
+	    pBookmark = NULL;
+	}
+    }
+    
+    fl_BlockLayout * pBlockLast = NULL;
+    
+    if(pBookmark)
+    {
+	UT_uint32 i = 0;
+	fp_BookmarkRun * pB[2] = {NULL,NULL};
+	fp_Run * pRun;
+	fl_BlockLayout * pBlockStart = pBlock;
+	bool bFound = false;
+	
+	while(pBlock)
+	{
+	    pRun = pBlock->getFirstRun();
+	    while(pRun)
+	    {
+		if(pRun->getType()== FPRUN_BOOKMARK)
+		{
+		    fp_BookmarkRun * pBR = static_cast<fp_BookmarkRun*>(pRun);
+		    if(!strcmp(pBR->getName(),pBookmark))
+		    {
+			pB[i] = pBR;
+			i++;
+			if(i>1)
+			{
+			    bFound = true;
+			    break;
+			}
+		    }
+		}
+		
+		pRun = pRun->getNextRun();
+	    }
+	    
+	    if(bFound)
+	    {
+		break;
+	    }
+	    pBlock = pBlock->getNextBlockInDocument();
+	}
+	
+	if(pB[0] && pB[1])
+	{
+	    pBlockLast = pB[1]->getBlock();
+	    
+	    pBlock = pB[0]->getBlock();
+	    PT_DocPosition pos1 = pB[0]->getBookmarkedDocPosition(false);
+	    
+	    if(pBlock->getPosition(true) < pos1)
+	    {
+		pBlock = pBlock->getNextBlockInDocument();
+	    }
+	}
+	else
+	{
+	    UT_ASSERT_HARMLESS( UT_SHOULD_NOT_HAPPEN );
+	    pBlock = pBlockStart;
+	}
+    }
+    
+    // clear any existing contents
+    _purgeLayout();
+    
+    while(pBlock)
+    {
+	pBlock->getStyle(sStyle);
+	if(isStyleInTOC(sStyle))
+	{
+	    filled = true;
+	    addBlock(pBlock, false);
+	}
+	if(pBlockLast && pBlockLast == pBlock)
+	{	    
+	    break;
+	}
+	pBlock = pBlock->getNextBlockInDocument();
+    }
+    if(m_bTOCHeading)
+    {
+	PD_Style * pStyle = NULL;
+	m_pDoc->getStyle(m_sTOCHeadingStyle.utf8_str(), &pStyle);
+	if(pStyle == NULL)
+	{
+	    m_pDoc->getStyle("Heading 1", &pStyle);
+	}
+	PT_AttrPropIndex indexAP = pStyle->getIndexAP();
+	
+	fl_BlockLayout * pNewBlock = static_cast<fl_BlockLayout *>(insert(getStruxDocHandle(),NULL,
+									  indexAP,FL_CONTAINER_BLOCK));
+	pNewBlock->_doInsertTOCHeadingRun(0);
+    }
+
+
+    return filled;
+}
