@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -59,7 +59,8 @@ fp_FrameContainer::fp_FrameContainer(fl_SectionLayout* pSectionLayout)
 	  m_bIsTopBot(false),
 	  m_bIsLeftWrapped(false),
 	  m_bIsRightWrapped(false),
-	  m_iPreferedPageNo(-1)
+	  m_iPreferedPageNo(-1),
+	  m_iPreferedColumnNo(0)
 {
 }
 
@@ -113,14 +114,6 @@ bool fp_FrameContainer::isAbove(void)
 {
   return  m_bIsAbove;
 }
-/*!
- * Returns true if the frame should be relocated before placing on a page
- */
-bool fp_FrameContainer::isRelocate(void) const
-{
-     fl_FrameLayout * pFL = static_cast<fl_FrameLayout *>(getSectionLayout());
-     return pFL->isRelocate();
-}
 /*!
  * Returns true if the supplied screen rectangle overlaps with frame
  * container. This method takes account of transparening and tight wrapping.
@@ -207,11 +200,31 @@ void fp_FrameContainer::setPreferedPageNo(UT_sint32 i)
      UT_UTF8String sVal;
      UT_UTF8String_sprintf(sVal,"%d",i);
      const char * attr = PT_PROPS_ATTRIBUTE_NAME;
-     UT_UTF8String sAttVal = "pref-page:";
+     UT_UTF8String sAttVal = "frame-pref-page:";
      sAttVal += sVal.utf8_str();
      
      pDoc->changeStruxAttsNoUpdate(pFL->getStruxDocHandle(),attr,sAttVal.utf8_str());
 }
+
+void fp_FrameContainer::setPreferedColumnNo(UT_sint32 i)
+{
+     if(m_iPreferedColumnNo == i)
+       return;
+     m_iPreferedColumnNo =  i;
+     fl_FrameLayout * pFL = static_cast<fl_FrameLayout *>(getSectionLayout());
+     FL_DocLayout * pDL = pFL->getDocLayout();
+     if(pDL->isLayoutFilling())
+       return;
+     PD_Document * pDoc = pDL->getDocument();
+     UT_UTF8String sVal;
+     UT_UTF8String_sprintf(sVal,"%d",i);
+     const char * attr = PT_PROPS_ATTRIBUTE_NAME;
+     UT_UTF8String sAttVal = "frame-pref-column:";
+     sAttVal += sVal.utf8_str();
+     
+     pDoc->changeStruxAttsNoUpdate(pFL->getStruxDocHandle(),attr,sAttVal.utf8_str());
+}
+
 /*!
  * This method returns the padding to be applied between a line approaching
  * wrapped frame or image from the left. 
@@ -669,7 +682,7 @@ void fp_FrameContainer::draw(dg_DrawArgs* pDA)
 		m_bNeverDrawn = false;
 	}
 	UT_uint32 count = countCons();
-	UT_DEBUGMSG(("Number of containers in frame %d \n",count));
+	xxx_UT_DEBUGMSG(("Number of containers in frame %d \n",count));
 	const UT_Rect * pPrevRect = pDA->pG->getClipRect();
 	UT_Rect * pRect = getScreenRect();
 	UT_Rect newRect;
