@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include "pp_Revision.h"
@@ -284,7 +284,8 @@ std::string PP_Revision::toString() const
 
 bool PP_Revision::onlyContainsAbiwordChangeTrackingMarkup() const
 {
-    UT_DEBUGMSG(("onlyContainsAbiwordChangeTrackingMarkup(top) ac:%d pc:%d\n", getAttributeCount(), getPropertyCount() ));
+    UT_DEBUGMSG(("onlyContainsAbiwordChangeTrackingMarkup(top) ac:%ld pc:%ld\n",
+		 (long)getAttributeCount(), (long)getPropertyCount() ));
 
     if( !getAttributeCount() )
         return false;
@@ -1144,29 +1145,6 @@ void PP_RevisionAttr::mergeAll( const PP_RevisionAttr& ra )
     _clear();
     std::string tmp = (std::string)us.getXMLstring() + "," + ra.getXMLstring();
 
-    /*
-     * This is a heavy debug block for testing.
-     */
-    if( DEBUG_MERGEALL )
-    {
-        UT_DEBUGMSG(("ODTCT ra::merge() ===================\n" ));
-        UT_DEBUGMSG(("ODTCT ra::merge() old:%s\n", us.getXMLstring() ));
-        UT_DEBUGMSG(("ODTCT ra::merge() new:%s\n", ra.getXMLstring() ));
-        UT_DEBUGMSG(("ODTCT ra::merge() ret:%s\n", tmp.c_str()  ));
-        for( int i=0; i < us.getRevisionsCount(); ++i )
-        {
-            const PP_Revision* r = us.getNthRevision( i );
-            UT_DEBUGMSG(("ODTCT ra::merge() old r:%d id:%d t:%d attr:%s\n", i, r->getId(), r->getType(), r->getAttrsString() ));
-            UT_DEBUGMSG(("ODTCT ra::merge() old r:%d id:%d t:%d prop:%s\n", i, r->getId(), r->getType(), r->getPropsString() ));
-        }
-        for( int i=0; i < ra.getRevisionsCount(); ++i )
-        {
-            const PP_Revision* r = ra.getNthRevision( i );
-            UT_DEBUGMSG(("ODTCT ra::merge() new r:%d id:%d t:%d attr:%s\n", i, r->getId(), r->getType(), r->getAttrsString() ));
-            UT_DEBUGMSG(("ODTCT ra::merge() new r:%d id:%d t:%d prop:%s\n", i, r->getId(), r->getType(), r->getPropsString() ));
-        }
-    }
-    
     revidx_t oldidx = toIndex( us );
     revidx_t newidx = toIndex( ra );
 
@@ -1381,7 +1359,7 @@ void PP_RevisionAttr::removeAllHigherOrEqualIds(UT_uint32 iId)
  */
 void PP_RevisionAttr::_refreshString() const
 {
-	char buf[30];
+  //	char buf[30];
 	m_sXMLstring.clear();
 	UT_uint32 iCount = m_vRev.getItemCount();
 
@@ -1565,7 +1543,7 @@ UT_uint32 PP_RevisionAttr::getHighestRevisionNumberWithAttribute( const gchar *
 {
     const PP_Revision* r = 0;
 
-    for( int raIdx = 0;
+    for( UT_uint32 raIdx = 0;
          raIdx < getRevisionsCount() && (r = getNthRevision( raIdx ));
          raIdx++ )
     {
