@@ -2,7 +2,7 @@
 
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
- * Copyright (C) 2003, 2009 Hubert Figuiere
+ * Copyright (C) 2003, 2009, 2011 Hubert Figuiere
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,8 +16,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #import <Cocoa/Cocoa.h>
@@ -105,11 +105,10 @@ void AP_CocoaDialog_Goto::notifyActiveFrame(XAP_Frame * /*pFrame*/)
 
 - (id)initFromNib
 {
-	if(![super initWithWindowNibName:@"ap_CocoaDialog_Goto"]) {
-		return nil;
+	if((self = [super initWithWindowNibName:@"ap_CocoaDialog_Goto"])) {
+		_xap = NULL;
+		m_jumpTarget = AP_JUMPTARGET_PAGE;
 	}
-	_xap = NULL;
-	m_jumpTarget = AP_JUMPTARGET_PAGE;
 	return self;
 }
 
@@ -164,13 +163,13 @@ void AP_CocoaDialog_Goto::notifyActiveFrame(XAP_Frame * /*pFrame*/)
 		[_bookmarkName setHasVerticalScroller:YES];
 	}
 	for(UT_sint32 i = 0; i < count; i++) {
-		[_bookmarkName addItemWithObjectValue:[NSString stringWithUTF8String:_xap->getNthExistingBookmark(i)]];
+		[_bookmarkName addItemWithObjectValue:[NSString stringWithUTF8String:_xap->getNthExistingBookmark(i).c_str()]];
 	}
 	if(count) {
 		[_bookmarkName selectItemAtIndex:0];
 	}
 	
-	m_docCount = _xap->getView()->countWords();
+	m_docCount = _xap->getView()->countWords(false);
 	NSNumberFormatter *formatter;
 	formatter = [_pageNum formatter];
 	[formatter setMinimum:[NSNumber numberWithInt:1]];
