@@ -1,6 +1,6 @@
 /* AbiWord
  * Copyright (C) 2000-2002 AbiSource, Inc.
- * Copyright (C) 2009 Hubert Figuiere
+ * Copyright (C) 2009, 2013 Hubert Figuiere
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -14,8 +14,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -24,6 +24,7 @@
 // This header defines some functions for Unix dialogs,
 // like centering them, measuring them, etc.
 #include "xap_UnixDialogHelper.h"
+#include "xap_Gtk2Compat.h"
 
 #include "xap_App.h"
 #include "xap_UnixApp.h"
@@ -53,10 +54,10 @@ static void s_color_changed(GtkWidget * csel,
 {
 	UT_ASSERT(csel && dlg);
   
-	GtkColorSelection * w = GTK_COLOR_SELECTION(csel);
-	GdkColor cur;
+	GtkColorChooser * w = GTK_COLOR_CHOOSER(csel);
+	GdkRGBA cur;
 
-	gtk_color_selection_get_current_color (w, &cur);
+	gtk_color_chooser_get_rgba (w, &cur);
 	UT_RGBColor * rgbcolor = UT_UnixGdkColorToRGBColor(cur);
 	UT_HashColor hash_color;
 	dlg->setColor (hash_color.setColor(*rgbcolor) + 1); // return with # prefix
@@ -107,22 +108,22 @@ GtkWidget * AP_UnixDialog_Background::_constructWindow (void)
 	GtkWidget * dlg;
 
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
-	UT_UTF8String s;
+	std::string s;
 	
 	if(isForeground())
 	{
 		pSS->getValueUTF8(AP_STRING_ID_DLG_Background_TitleFore,s);
-		dlg = abiDialogNew ( "background dialog", TRUE, s.utf8_str()) ;
+		dlg = abiDialogNew ( "background dialog", TRUE, s.c_str()) ;
 	}
 	else if(isHighlight())
 	{
 		pSS->getValueUTF8(AP_STRING_ID_DLG_Background_TitleHighlight,s);
-		dlg = abiDialogNew ( "background dialog", TRUE, s.utf8_str()) ;
+		dlg = abiDialogNew ( "background dialog", TRUE, s.c_str()) ;
 	}
 	else
 	{
 		pSS->getValueUTF8(AP_STRING_ID_DLG_Background_Title,s);
-		dlg = abiDialogNew ( "background dialog", TRUE, s.utf8_str()) ;
+		dlg = abiDialogNew ( "background dialog", TRUE, s.c_str()) ;
 	}
 
 	gtk_window_set_resizable (GTK_WINDOW (dlg), false);
@@ -144,9 +145,11 @@ void AP_UnixDialog_Background::_constructWindowContents (GtkWidget * parent)
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 	gtk_container_add (GTK_CONTAINER(parent), vbox);
 
-	colorsel = gtk_color_selection_new();
+	colorsel = gtk_color_chooser_widget_new();
+#if !GTK_CHECK_VERSION(3,4,0)
 	gtk_color_selection_set_has_palette (GTK_COLOR_SELECTION (colorsel), TRUE);
-	gtk_color_selection_set_has_opacity_control(GTK_COLOR_SELECTION(colorsel), false);
+#endif
+	gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(colorsel), false);
 	gtk_widget_show (colorsel);
 	gtk_container_add (GTK_CONTAINER(vbox), colorsel);
 
@@ -156,10 +159,10 @@ void AP_UnixDialog_Background::_constructWindowContents (GtkWidget * parent)
 	{
 		UT_parseColor(pszC,c);
 	}
-	GdkColor *gcolor = UT_UnixRGBColorToGdkColor(c);
+	GdkRGBA *gcolor = UT_UnixRGBColorToGdkRGBA(c);
 
-    gtk_color_selection_set_current_color ( GTK_COLOR_SELECTION ( colorsel ), gcolor);
-	gdk_color_free(gcolor);
+	gtk_color_chooser_set_rgba( GTK_COLOR_CHOOSER ( colorsel ), gcolor);
+	gdk_rgba_free(gcolor);
 
 	m_wColorsel = colorsel;
 //
@@ -167,7 +170,7 @@ void AP_UnixDialog_Background::_constructWindowContents (GtkWidget * parent)
 //
 	GtkWidget * alignment = NULL;
 	GtkWidget * clearColor = NULL;
-	UT_UTF8String s;
+	std::string s;
 	
 	if(!isForeground())
 	{
@@ -175,12 +178,12 @@ void AP_UnixDialog_Background::_constructWindowContents (GtkWidget * parent)
 		if(isHighlight())
 		{
 			pSS->getValueUTF8 (AP_STRING_ID_DLG_Background_ClearHighlight,s);
-			clearColor = gtk_button_new_with_label (s.utf8_str());
+			clearColor = gtk_button_new_with_label (s.c_str());
 		}
 		else
 		{
 			pSS->getValueUTF8 (AP_STRING_ID_DLG_Background_ClearClr,s);
-			clearColor = gtk_button_new_with_label (s.utf8_str());
+			clearColor = gtk_button_new_with_label (s.c_str());
 		}
 		gtk_widget_show(clearColor);
 
@@ -193,9 +196,14 @@ void AP_UnixDialog_Background::_constructWindowContents (GtkWidget * parent)
 						G_CALLBACK(s_color_cleared),
 						(gpointer) this);
 	}
-	g_signal_connect (G_OBJECT(colorsel), "color-changed",
-							G_CALLBACK(s_color_changed),
-						(gpointer) this);
+	g_signal_connect (G_OBJECT(colorsel),
+#if GTK_CHECK_VERSION(3,4,0)
+			  "color-activated",
+#else
+			  "color-changed",
+#endif
+			  G_CALLBACK(s_color_changed),
+			  (gpointer) this);
 }
 
 void AP_UnixDialog_Background::eventOk (void)
@@ -211,14 +219,19 @@ void AP_UnixDialog_Background::eventCancel (void)
 void AP_UnixDialog_Background::colorCleared(void)
 {
 	setColor(NULL);
-	GdkColor gcolor;
+	GdkRGBA gcolor;
+#if !GTK_CHECK_VERSION(3,0,0)
 	gcolor.pixel = 0;
 	gcolor.red = 0xffff;
 	gcolor.blue = 0xffff;
 	gcolor.green = 0xffff;
-	gtk_color_selection_set_current_color (GTK_COLOR_SELECTION(m_wColorsel),
-										   &gcolor);
-}	
-	
-
+#else
+	gcolor.red = 1.0;
+	gcolor.blue = 1.0;
+	gcolor.green = 1.0;
+	gcolor.alpha = 1.0;
+#endif
+	gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER(m_wColorsel),
+                                    &gcolor);
+}
 
