@@ -13,8 +13,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -173,12 +173,12 @@ void AP_UnixDialog_Latex::constructDialog(void)
 {	
 	const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
 
-	// get the path where our UI file is located
-	std::string ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_Latex.xml";
-
 	// load the dialog from the UI file
-	GtkBuilder* builder = gtk_builder_new();
-	gtk_builder_add_from_file(builder, ui_path.c_str(), NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Latex.ui");
+#else
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Latex-2.ui");
+#endif
 
         // Update our member variables with the important widgets that
         // might need to be queried or altered later
