@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -134,7 +134,7 @@ void AP_UnixDialog_Options::runModal ( XAP_Frame * pFrame )
 /// All this color selection code is stolen from the ap_UnixDialog_Background
 /// dialog
 ///
-void AP_UnixDialog_Options::s_real_color_changed(GdkColor & gdkcolor, AP_UnixDialog_Options * dlg)
+void AP_UnixDialog_Options::s_real_color_changed(GdkRGBA & gdkcolor, AP_UnixDialog_Options * dlg)
 {
 
 	UT_RGBColor * rgbcolor = UT_UnixGdkColorToRGBColor(gdkcolor);
@@ -162,11 +162,9 @@ void AP_UnixDialog_Options::s_color_changed ( GtkColorSelection *csel,
     AP_UnixDialog_Options * dlg = static_cast<AP_UnixDialog_Options *> ( data );
     UT_ASSERT ( csel && dlg );
 
-	GdkColor gdkcolor;
-
-	gtk_color_selection_get_current_color(csel, &gdkcolor);
-
-    s_real_color_changed(gdkcolor, dlg);
+	GdkRGBA rgba;
+	gtk_color_selection_get_current_rgba(csel, &rgba);
+    s_real_color_changed(rgba, dlg);
 }
 #endif
 
@@ -200,15 +198,19 @@ void AP_UnixDialog_Options::event_ChooseTransparentColor ( void )
 // Run the Background dialog over the options? No the title is wrong.
 //
     GtkWidget *colorsel;
-    UT_UTF8String s;
+	std::string s;
 
     const XAP_StringSet * pSS = m_pApp->getStringSet();
 
-    GtkBuilder * builder = newDialogBuilder("ap_UnixDialog_Options_ColorSel.xml");
+#if GTK_CHECK_VERSION(3,0,0)
+    GtkBuilder * builder = newDialogBuilder("ap_UnixDialog_Options_ColorSel.ui");
+#else
+    GtkBuilder * builder = newDialogBuilder("ap_UnixDialog_Options_ColorSel-2.ui");
+#endif
 
     dlg = WID ( "ap_UnixDialog_Options_ColorSel" );
     pSS->getValueUTF8 ( AP_STRING_ID_DLG_Options_Label_ChooseForTransparent, s );
-    abiDialogSetTitle ( dlg, s.utf8_str() );
+    abiDialogSetTitle ( dlg, "%s", s.c_str() );
 
     colorsel = WID ( "csColorSel" );
 
@@ -222,10 +224,10 @@ void AP_UnixDialog_Options::event_ChooseTransparentColor ( void )
 
     UT_RGBColor c;
     UT_parseColor ( m_CurrentTransparentColor,c );
-	GdkColor *gcolor = UT_UnixRGBColorToGdkColor(c);
+	GdkRGBA *gcolor = UT_UnixRGBColorToGdkRGBA(c);
 
-    gtk_color_selection_set_current_color ( GTK_COLOR_SELECTION ( colorsel ), gcolor);
-	gdk_color_free(gcolor);
+    gtk_color_selection_set_current_rgba ( GTK_COLOR_SELECTION ( colorsel ), gcolor);
+	gdk_rgba_free(gcolor);
 
     // run into the gtk main loop for this window. If the reponse is 0, the user pressed Defaults.
     // Don't destroy it if he did so.
@@ -234,9 +236,9 @@ void AP_UnixDialog_Options::event_ChooseTransparentColor ( void )
         strncpy ( m_CurrentTransparentColor,static_cast<const gchar *> ( "ffffff" ),9 );
 
         UT_parseColor ( m_CurrentTransparentColor,c );
-		gcolor = UT_UnixRGBColorToGdkColor(c);
-        gtk_color_selection_set_current_color ( GTK_COLOR_SELECTION ( colorsel ), gcolor );
-		gdk_color_free(gcolor);
+		gcolor = UT_UnixRGBColorToGdkRGBA(c);
+        gtk_color_chooser_set_rgba ( GTK_COLOR_CHOOSER ( colorsel ), gcolor );
+		gdk_rgba_free(gcolor);
     }
 #endif
 //
@@ -511,9 +513,13 @@ GtkWidget* AP_UnixDialog_Options::_constructWindow ()
 
     // get the path where our UI file is located
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON
-    dialogFileName = "ap_UnixHildonDialog_Options.xml";
+    dialogFileName = "ap_UnixHildonDialog_Options.ui";
 #else
-    dialogFileName = "ap_UnixDialog_Options.xml";
+#if GTK_CHECK_VERSION(3,0,0)
+    dialogFileName = "ap_UnixDialog_Options.ui";
+#else
+    dialogFileName = "ap_UnixDialog_Options-2.ui";	
+#endif
 #endif
 
     GtkBuilder * builder = newDialogBuilder(dialogFileName);
@@ -529,7 +535,7 @@ GtkWidget* AP_UnixDialog_Options::_constructWindow ()
     // set the dialog title
     std::string s;
     pSS->getValueUTF8(AP_STRING_ID_DLG_Options_OptionsTitle, s);
-    abiDialogSetTitle(mainWindow, s.c_str());
+    abiDialogSetTitle(mainWindow, "%s", s.c_str());
 
     // the control buttons
     g_signal_connect ( G_OBJECT ( m_buttonDefaults ),
