@@ -14,8 +14,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -46,6 +46,8 @@ const char * AP_Dialog_Goto::s_pJumpTargets[] = {
 	NULL,
 	NULL,
 //	"Picture",  TODO
+	NULL,
+	NULL,
 	NULL
 };
 
@@ -71,6 +73,8 @@ void AP_Dialog_Goto::_setupJumpTargets(void)
     s_pJumpTargets[1] = ::g_strdup(pSS->getValue (AP_STRING_ID_DLG_Goto_Target_Line));
     s_pJumpTargets[2] = ::g_strdup(pSS->getValue (AP_STRING_ID_DLG_Goto_Target_Bookmark));
     //s_pJumpTargets[2] = ::g_strdup(pSS->getValue (AP_STRING_ID_DLG_Goto_Target_Picture)); //TODO
+    s_pJumpTargets[3] = ::g_strdup(pSS->getValue (AP_STRING_ID_DLG_Goto_Target_XMLid));    
+    s_pJumpTargets[4] = ::g_strdup(pSS->getValue (AP_STRING_ID_DLG_Goto_Target_Annotation));    
 
 }
 
@@ -90,13 +94,12 @@ void AP_Dialog_Goto::ConstructWindowName(void)
 {
 	const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
 	gchar * tmp = NULL;
-	UT_uint32 title_width = 33;
 
 	std::string s;
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Goto_Title, s);
 	
 	UT_XML_cloneNoAmpersands(tmp, s.c_str());
-	BuildWindowName(m_WindowName, tmp, title_width);
+	BuildWindowName(m_WindowName, tmp, sizeof(m_WindowName));
 	FREEP(tmp);
 }							
 
@@ -195,8 +198,8 @@ UT_sint32 AP_Dialog_Goto::getExistingBookmarksCount() const
 	return m_pView->getDocument()->getBookmarkCount();
 }
 
-const gchar * AP_Dialog_Goto::getNthExistingBookmark(UT_sint32 n) const
+const std::string & AP_Dialog_Goto::getNthExistingBookmark(UT_sint32 n) const
 {
-	UT_return_val_if_fail (m_pView, NULL);
+	UT_ASSERT(m_pView);
 	return m_pView->getDocument()->getNthBookmark(n);
 }
