@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -128,8 +128,9 @@ bool AP_Dialog_Paragraph::setDialogData(const gchar ** pProps)
 				t = align_JUSTIFIED;
 			else if (strcmp(sz, "left") == 0)
 				t = align_LEFT;
-			else
+			else {
 				UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+			}
 
 			_setMenuItemValue(id_MENU_ALIGNMENT, t, op_INIT);
 		}
@@ -143,8 +144,9 @@ bool AP_Dialog_Paragraph::setDialogData(const gchar ** pProps)
 				t = check_FALSE;
 			else if (strcmp(sz, "rtl") == 0)
 				t = check_TRUE;
-			else
+			else {
 				UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+			}
 
 			_setCheckItemValue(id_CHECK_DOMDIRECTION, t, op_INIT);
 		}
