@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 
@@ -193,7 +193,7 @@ ap_bs_Mouse MouseTable[] =
 //	Button-2, Text-context
 //  { context	{ click				doubleclick		drag,		dbldrag,		release,	doublerelease	}},
 
-#ifdef TOOLKIT_GTK
+#ifdef TOOLKIT_GTK_ALL
 // special key binding for X11-style middle mouse selection (not to be confused with the clipboard)
 	{_CT _B2,	{ "pasteSelection",	"",				"",			"",				"",			""				}},
 	{_CH _B2,	{ "pasteSelection",	"",				"",			"",				"",			""				}},
