@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 /*****************************************************************
 ******************************************************************
@@ -285,7 +285,9 @@ menuitem(TABLE_SPLIT_TABLE)
 menuitem(TABLE_FORMAT)
 menuitem(TABLE_TEXTTOTABLE)
 menuitem(TABLE_TEXTTOTABLE_ALL)
-menuitem(TABLE_TEXTTOTABLE_NOSPACES)
+menuitem(TABLE_TEXTTOTABLE_COMMAS)
+menuitem(TABLE_TEXTTOTABLE_SPACES)
+menuitem(TABLE_TEXTTOTABLE_TABS)
 menuitem(TABLE_TABLETOTEXT)
 menuitem(TABLE_TABLETOTEXTCOMMAS)
 menuitem(TABLE_TABLETOTEXTTABS)
