@@ -16,8 +16,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,6 +31,7 @@
 #include "ut_debugmsg.h"
 #include "ev_Toolbar_Layouts.h"
 #include "ev_Toolbar_Actions.h"
+#include "xap_App.h"
 #include "xap_Toolbar_Layouts.h"
 #include "xap_Prefs.h"
 #include "xap_Prefs_SchemeIds.h"
@@ -160,7 +161,7 @@ XAP_Toolbar_Factory_lt * XAP_Toolbar_Factory_vec::getNth_lt(UT_uint32 i)
 
 void XAP_Toolbar_Factory_vec::insertItemBefore(void * p, XAP_Toolbar_Id id)
 {
-	UT_uint32 i = 0;
+	UT_sint32 i = 0;
 	bool bFound = false;
 	for(i=0; !bFound && (i< m_Vec_lt.getItemCount()); i++)
 	{
@@ -178,7 +179,7 @@ void XAP_Toolbar_Factory_vec::insertItemBefore(void * p, XAP_Toolbar_Id id)
 
 void XAP_Toolbar_Factory_vec::insertItemAfter(void * p, XAP_Toolbar_Id id)
 {
-	UT_uint32 i = 0;
+	UT_sint32 i = 0;
 	bool bFound = false;
 	for(i=0; !bFound && (i< m_Vec_lt.getItemCount()); i++)
 	{
@@ -207,7 +208,7 @@ void XAP_Toolbar_Factory_vec::insertLastItem(void * p)
 
 bool XAP_Toolbar_Factory_vec::removeToolbarId(XAP_Toolbar_Id id)
 {
-	UT_uint32 i = 0;
+	UT_sint32 i = 0;
 	bool bFound = false;
 	for(i=0; !bFound && (i< m_Vec_lt.getItemCount()); i++)
 	{
@@ -283,8 +284,9 @@ XAP_Toolbar_Factory::getToolbarNames(void)
 	for (i = 0; i < count; i++) {
 		XAP_Toolbar_Factory_vec * pVec = (XAP_Toolbar_Factory_vec *) m_vecTT.getNthItem(i);
 		XAP_String_Id label =  pVec->getLabelStringID();
-		UT_UTF8String * str = new UT_UTF8String;
-		pSS->getValueUTF8(label,*str);
+		std::string s;
+		pSS->getValueUTF8(label,s);
+		UT_UTF8String * str = new UT_UTF8String(s);
 		m_tbNames.addItem(str);
 	}
 	return m_tbNames;
@@ -330,7 +332,7 @@ EV_Toolbar_Layout * XAP_Toolbar_Factory::CreateToolbarLayout(const char * szName
 			for (k=0; k < pVec->getNrEntries(); k++)
 			{
 				XAP_Toolbar_Factory_lt * plt = pVec->getNth_lt(k);
-				bool bResult = pLayout->setLayoutItem(k, plt->m_id, plt->m_flags);
+				UT_DebugOnly<bool> bResult = pLayout->setLayoutItem(k, plt->m_id, plt->m_flags);
 				UT_ASSERT_HARMLESS(bResult);
 			}
 			break;
@@ -504,69 +506,6 @@ bool  XAP_Toolbar_Factory::removeIcon(const char * szName,
 	return true;
 }
 
-bool XAP_Toolbar_Factory::resetAllToolbarsToDefault(void)
-{
-	UT_uint32 count = m_vecTT.getItemCount();  // NO toolabrs
-	UT_uint32 i = 0;
-	XAP_Toolbar_Factory_vec * pVec = NULL;
-	for (i=0; i < count; i++)
-	{
-		pVec = (XAP_Toolbar_Factory_vec *) m_vecTT.getNthItem(i);
-		const char * szCurName =  pVec->getToolbarName();
-		resetToolbarToDefault(szCurName);
-	}
-	return true;
-}
-			
-bool  XAP_Toolbar_Factory::resetToolbarToDefault(const char * szName)
-{
-	UT_uint32 count = m_vecTT.getItemCount();  // NO toolabrs
-	UT_uint32 i = 0;
-	bool bFound = false;
-	const char * szCurName = NULL;
-	XAP_Toolbar_Factory_vec * pVec = NULL;
-	for (i=0; !bFound && (i < count); i++)
-	{
-		pVec = (XAP_Toolbar_Factory_vec *) m_vecTT.getNthItem(i);
-		szCurName =  g_strdup(pVec->getToolbarName());
-		if (g_ascii_strcasecmp(szName,szCurName)==0)
-		{
-			bFound = true;
-			break;
-		}
-		else
-		{
-			FREEP( szCurName );
-		}
-	}
-	UT_ASSERT_HARMLESS(bFound);
-	if(!bFound)
-	{
-		return false;
-	}
-	DELETEP(pVec);
-	UT_uint32 j = 0;
-	count = G_N_ELEMENTS(s_ttTable);
-	bFound = false;
-	for(j=0; !bFound &&( j < count); j++)
-	{
-		if(g_ascii_strcasecmp(szCurName,s_ttTable[j].m_name)== 0)
-		{
-			bFound = true;
-			break;
-		}
-	}
-	FREEP(szCurName);
-	UT_ASSERT_HARMLESS(bFound);
-	if(!bFound)
-	{
-		return false;
-	}
-	pVec = new XAP_Toolbar_Factory_vec(&s_ttTable[j]);
-	m_vecTT.setNthItem(i, (void *) pVec, NULL);
-	return true;
-}
-
 /*!
  * This method saves the current toolbar layouts in the current preference
  * scheme. There are 3 generic keys.
