@@ -19,8 +19,8 @@
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
-* 02111-1307, USA.
+* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+* 02110-1301 USA.
 */
 
 #include "ie_exp_HTML_Listener.h"
@@ -78,7 +78,7 @@ m_bHasMathMl(false)
 
 }
 
-bool IE_Exp_HTML_Listener::populate(PL_StruxFmtHandle /*sfh*/, const PX_ChangeRecord* pcr)
+bool IE_Exp_HTML_Listener::populate(fl_ContainerLayout* /*sfh*/, const PX_ChangeRecord* pcr)
 {
     if (m_bSkipSection)
         return true;
@@ -260,8 +260,8 @@ bool IE_Exp_HTML_Listener::populate(PL_StruxFmtHandle /*sfh*/, const PX_ChangeRe
     return true;
 }
 
-bool IE_Exp_HTML_Listener::populateStrux(PL_StruxDocHandle sdh, 
-	const PX_ChangeRecord* pcr, PL_StruxFmtHandle* psfh)
+bool IE_Exp_HTML_Listener::populateStrux(pf_Frag_Strux* sdh, 
+	const PX_ChangeRecord* pcr, fl_ContainerLayout** psfh)
 {
     
     UT_return_val_if_fail(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux, 
@@ -645,19 +645,19 @@ bool IE_Exp_HTML_Listener::populateStrux(PL_StruxDocHandle sdh,
     return returnVal;
 }
 
-bool IE_Exp_HTML_Listener::insertStrux(PL_StruxFmtHandle /*sfh*/,
+bool IE_Exp_HTML_Listener::insertStrux(fl_ContainerLayout* /*sfh*/,
                                        const PX_ChangeRecord * /*pcr*/,
-                                       PL_StruxDocHandle /*sdh*/,
+                                       pf_Frag_Strux* /*sdh*/,
                                        PL_ListenerId /*lid*/,
                                        void (* /*pfnBindHandles*/) 
-									   (PL_StruxDocHandle sdhNew,
+									   (pf_Frag_Strux* sdhNew,
                                        PL_ListenerId lid,
-                                       PL_StruxFmtHandle sfhNew))
+                                       fl_ContainerLayout* sfhNew))
 {
     return true;
 }
 
-bool IE_Exp_HTML_Listener::change(PL_StruxFmtHandle /*sfh*/, 
+bool IE_Exp_HTML_Listener::change(fl_ContainerLayout* /*sfh*/, 
 								  const PX_ChangeRecord* /*pcr*/)
 {
     return true;
@@ -1007,7 +1007,6 @@ void IE_Exp_HTML_Listener::_closeSpan(void)
         return;
 
     m_bInSpan = false;
-    UT_DEBUGMSG(("CLOSED SPAN\n"));
     m_pCurrentImpl->closeSpan();
     return;
 }
@@ -1121,8 +1120,6 @@ void IE_Exp_HTML_Listener::_openHeading(PT_AttrPropIndex api, size_t level,
     const PP_AttrProp* pAP;
     bool ok;
 
-    m_bInBlock = true;
-
     ok = m_pDocument->getAttrProp(api, &pAP);
     if (!ok) 
     {
@@ -2417,10 +2414,10 @@ void IE_Exp_HTML_Listener::_insertLinks()
 
 void IE_Exp_HTML_Listener::_insertTitle()
 {
-	UT_UTF8String metaProp;
+	std::string metaProp;
 
     if (m_pDocument->getMetaDataProp(PD_META_KEY_TITLE, metaProp) 
-									 && metaProp.size())
+									 && !metaProp.empty())
 	{
         m_pCurrentImpl->insertTitle(metaProp);
 	} else
@@ -2431,23 +2428,23 @@ void IE_Exp_HTML_Listener::_insertTitle()
 
 void IE_Exp_HTML_Listener::_insertMeta()
 {
-    UT_UTF8String metaProp;
+	std::string metaProp;
 
     if (m_pDocument->getMetaDataProp(PD_META_KEY_TITLE, metaProp) 
 									 && metaProp.size())
-        m_pCurrentImpl->insertMeta("title", metaProp);
+        m_pCurrentImpl->insertMeta("title", metaProp, std::string());
 
     if (m_pDocument->getMetaDataProp(PD_META_KEY_CREATOR, metaProp) 
 									 && metaProp.size())
-        m_pCurrentImpl->insertMeta("author", metaProp);
+        m_pCurrentImpl->insertMeta("author", metaProp, std::string());
 
     if (m_pDocument->getMetaDataProp(PD_META_KEY_KEYWORDS, metaProp) 
 									 && metaProp.size())
-        m_pCurrentImpl->insertMeta("keywords", metaProp);
+        m_pCurrentImpl->insertMeta("keywords", metaProp, std::string());
 
     if (m_pDocument->getMetaDataProp(PD_META_KEY_SUBJECT, metaProp) 
 									 && metaProp.size())
-        m_pCurrentImpl->insertMeta("subject", metaProp);
+        m_pCurrentImpl->insertMeta("subject", metaProp, std::string());
 }
     
 void IE_Exp_HTML_Listener::_insertTOC(PT_AttrPropIndex api)
@@ -2488,7 +2485,7 @@ void IE_Exp_HTML_Listener::_insertTOC(PT_AttrPropIndex api)
     ok = pAP->getProperty("toc-heading", szTOCHeading);
     if (!(ok && szTOCHeading))
     {
-       szTOCHeading = fl_TOCLayout::getDefaultHeading().utf8_str();
+       szTOCHeading = fl_TOCLayout::getDefaultHeading().c_str();
     }
     
     std::vector<UT_UTF8String> tocItems;
@@ -3088,7 +3085,7 @@ void IE_Exp_HTML_Listener::_setCellWidthInches()
 		// probably covering up some sort of issue
 		// but we assert above, so we'll notice it again
 		if (i < (UT_sint32) m_vecDWidths.size())
-			tot += *(m_vecDWidths.getNthItem(i));
+			tot += m_vecDWidths.getNthItem(i);
 	}
 	m_dCellWidthInches = tot;
 
@@ -3106,7 +3103,6 @@ void IE_Exp_HTML_Listener::_fillColWidthsVector()
 	UT_DEBUGMSG(("Number columns in table %d \n",m_tableHelper.getNumCols ()));
 	if(m_vecDWidths.getItemCount() > 0)
 	{
-		UT_VECTOR_PURGEALL(double *,m_vecDWidths);
 		m_vecDWidths.clear();
 	}
 	if(pszColumnProps && *pszColumnProps)
@@ -3145,9 +3141,7 @@ void IE_Exp_HTML_Listener::_fillColWidthsVector()
 			{
 				UT_String sSub = sProps.substr(i,(j-i));
 				i = j + 1;
-				double * pDWidth = new double;
-				*pDWidth = UT_convertToInches(sSub.c_str());
-				m_vecDWidths.addItem(pDWidth);
+				m_vecDWidths.addItem(UT_convertToInches(sSub.c_str()));
 			}
 		}
 	}
@@ -3163,9 +3157,7 @@ void IE_Exp_HTML_Listener::_fillColWidthsVector()
 		UT_sint32 i = 0;
 		for(i =0; i< nCols; i++)
 		{
-			double * pDWidth = new double;
-			*pDWidth = colWidth;
-			m_vecDWidths.addItem(pDWidth);
+			m_vecDWidths.addItem(colWidth);
 		}
 	}
 }
