@@ -1,4 +1,4 @@
-/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
@@ -15,8 +15,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #include "ie_impGraphic.h"
@@ -164,6 +164,9 @@ std::vector<std::string> & IE_ImpGraphic::getSupportedSuffixes()
  */
 const char * IE_ImpGraphic::getMimeTypeForSuffix(const char * suffix)
 {
+	if (!suffix || !(*suffix))
+		return NULL;
+		
 	if (suffix[0] == '.') {
 		suffix++;
 	}
@@ -469,19 +472,22 @@ UT_Error IE_ImpGraphic::constructImporter(GsfInput * input,
 					content_confidence = s->recognizeContents(input);
 				}
 
-				const char * suffix = UT_pathSuffix(gsf_input_name (input));
-				if (suffix) {
+				const char * name = gsf_input_name (input);
+				// we can have an empty name (NULL) because we can have a memory stream.
+				if(name) {
 					const IE_SuffixConfidence * sc = s->getSuffixConfidence();
-					while (sc && !sc->suffix.empty()) {
+					while (sc && !sc->suffix.empty() && suffix_confidence != UT_CONFIDENCE_PERFECT) {
 						/* suffixes do not have a leading '.' */
-						if (0 == g_ascii_strcasecmp(sc->suffix.c_str(), suffix+1) && 
+						// we use g_str_has_suffix like this to make sure we properly autodetect the extensions
+						// of files that have dots in their names, like foo.bar.png
+						std::string suffix = std::string(".") + sc->suffix;
+						if (g_str_has_suffix(name, suffix.c_str()) && 
 							sc->confidence > suffix_confidence) {
 							suffix_confidence = sc->confidence;
 						}
 						sc++;
 					}
 				}
-				
 				UT_Confidence_t confidence = s_condfidence_heuristic ( content_confidence, 
 																	   suffix_confidence ) ;
 				
@@ -568,54 +574,6 @@ UT_Error IE_ImpGraphic::importGraphic(const char * szFilename,
 	return res;
 }
 
-UT_Error IE_ImpGraphic::convertGraphic(UT_ByteBuf* pBB,
-									   UT_ByteBuf** ppBB)
-{
-	UT_return_val_if_fail(pBB != NULL, UT_IE_FILENOTFOUND);
-	UT_return_val_if_fail(ppBB != NULL, UT_ERROR);
-
-	FG_Graphic * graphic = NULL;
-	UT_Error result;
-
-	result = IE_ImpGraphic::loadGraphic(*pBB, IEGFT_Unknown, &graphic);
-
-	// method assumes that we take ownership of pBB
-	DELETEP(pBB);
-
-	if (result != UT_OK)
-		return result;
-
-	const UT_ByteBuf * graphic_bytebuf;
-
-	if (graphic->getType() == FGT_Raster) {
-		graphic_bytebuf = static_cast<FG_GraphicRaster *>(graphic)->getRaster_PNG();
-	} else if (graphic->getType() == FGT_Vector) {
-		graphic_bytebuf = static_cast<FG_GraphicVector *>(graphic)->getVector_SVG();
-	} else {
-		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-		DELETEP(graphic);
-		return UT_ERROR;
-	}
-
-
-	UT_ByteBuf *out_graphic = new UT_ByteBuf();
-	if (!out_graphic) {
-		DELETEP(graphic);
-		return UT_IE_NOMEMORY;
-	}
-		
-	if (!out_graphic->ins (0, graphic_bytebuf->getPointer(0), graphic_bytebuf->getLength()))
-		{
-			DELETEP(graphic);
-			DELETEP(out_graphic);
-			return UT_IE_NOMEMORY;
-		}
-
-	DELETEP(graphic);
-	*ppBB = out_graphic;
-
-	return UT_OK;
-}
 
 UT_Error IE_ImpGraphic::loadGraphic(const char * szFilename,
 									IEGraphicFileType iegft,
